% Makes Figures 1.5, 1.6, and 1.7

% Plot specifications
lineplotspec = {'color','k','linewidth',3};
dotplotspec = {'o','markersize',4,'markeredgecolor','k','markerfacecolor','k'};
textspec = {'fontsize',18,'fontweight','bold'};

% Create data from additive normal model
randn('state',0)
n = 1000;
axy = [0 1.1 0 4];
x = makegrid(n,0);
f = sin(exp(x.*log(1+2*pi))); f = 1 + f - min(f);
plot(x,f,lineplotspec{:})
axis(axy), axis off, xtick = [0 1]; drawaxes('xtick',xtick,textspec{:})
print -deps smoothtestsignal.eps

Z = randn(size(f));
stdev = 0.5;
y = f+stdev*Z;
plot(x,y,lineplotspec{:})
axis(axy), axis off, xtick = [0 1]; drawaxes('xtick',xtick,textspec{:})
print -deps noisysmoothtestsignal.eps

% Compute Fourier transform of observations without noise
F = fft(f); F = fftshift(F);
% plot(-ceil(n/2)+1:floor(n/2),abs(F),lineplotspec{:})
plot(-ceil(n/2):floor(n/2)-1,abs(F),lineplotspec{:},dotplotspec{:})

axFourier = axis; axFourier(4) = axFourier(4)/10; axFourier(1:2) = [-1 1]*30;
xticks = [axFourier(1)+10 0 axFourier(2)-10];
axis(axFourier)
axis off, drawaxes('xticks',xticks,textspec{:})
print -depsc spectrumsmoothf.eps

% Compute Fourier transform of observations with noise
Y = fft(y); Y = fftshift(Y);
% plot(-ceil(n/2)+1:floor(n/2),abs(Y),lineplotspec{:})
plot(-ceil(n/2):floor(n/2)-1,abs(Y),lineplotspec{:},dotplotspec{:})
axis(axFourier)
axis off, drawaxes('xticks',xticks,textspec{:})
print -depsc spectrumsmoothy.eps

% Filter away high frequencies
cutoff = 0.01;
window = zeros(size(Y));
windowlowerbound = floor(n/2-cutoff*n/2);
windowupperbound = ceil(n/2+cutoff*n/2);
window(windowlowerbound:windowupperbound) = 1;
Yfilt = Y.*window;
% plot(-ceil(n/2)+1:floor(n/2),abs(Yfilt),lineplotspec{:})
plot(-ceil(n/2):floor(n/2)-1,abs(Yfilt),lineplotspec{:},dotplotspec{:})
axis(axFourier)
axis off, drawaxes('xticks',xticks,textspec{:})
print -depsc filteredspectrumsmoothy.eps

% Inverse Fourier transforms
Yfilt = ifftshift(Yfilt);
yfilt = abs(ifft(Yfilt));
plot(x,yfilt,lineplotspec{:})
axis(axy), axis off, xtick = [0 1]; drawaxes('xtick',xtick,textspec{:})
print -depsc filteredsmoothsignal.eps

% Orthogonal projection onto sinusoid basis 
x = column(x); y = column(y);
X = [ones(n,1) sin(2*pi*x) cos(2*pi*x) sin(4*pi*x) cos(4*pi*x) ...
   sin(6*pi*x) cos(6*pi*x) sin(8*pi*x) cos(8*pi*x) sin(10*pi*x) cos(10*pi*x)];
fest = X*((X'*X)\(X'*y));
plot(x,yfilt,lineplotspec{:})
hold on
plot(x,fest,'r')
hold off

plot(x,X,lineplotspec{:})
axy(3:4) = 1.1*[-1 1];
axis(axy)
axis off

