% Makes Figure 4.7
% See also makefigBsplines1234.m

% Default values
if exist('makeepsfiles') ~= 1, makeepsfiles = false; end
if exist('randomknots') ~= 1, randomknots = false; end
if exist('dualmom') ~= 1, dualmom = 5; end
if exist('knotsasinbook') ~= 1, knotsasinbook = true; end
if exist('nn') ~= 1, nn = 1000; end
if exist('figsize') ~= 1, figsize = [1280 420]; end
if exist('papersize') ~= 1, papersize = figsize/96; end
if exist('figpaperpos') ~= 1, figpaperpos = [0 0 papersize]; end
if exist('linewidth') ~= 1, linewidth = 3; end
if exist('markersize') ~= 1, markersize = 12; end

knotopt = {'ko','markersize',markersize,'markerfacecolor','k'};
% i.e.:   {'o','markersize',markersize,'markeredgecolor','k','markerfacecolor','k'};
lineopt = {'linewidth',linewidth,'color','k'};
greylineopt = {'linewidth',linewidth,'color',0.6*[1 1 1]};
ptilde = dualmom; 

if exist('knots')==1,
   knots = column(knots); nknots = length(knots);
elseif knotsasinbook==true,
   chooseknotsasinbook; knots = knots7;
   nknots = 7;
else
   if randomknots == false, rand('state',2), end
   if exist('nknots') ~= 1, nknots = max(7,2*ptilde-1); end
   knots = sort(rand(nknots,1));
   knots = (knots-knots(1))/(knots(nknots)-knots(1));
end
nL = nknots;
xx = (1:nn)/nn;

% Construct B-spline basis
PhiB = Bsplinebasis(xx,knots,ptilde);
PhiBref = Bsplinebasisbyrefinement(xx,knots,ptilde,false);
PhiBknots = Bsplinebasis(knots,knots,ptilde,false);
if ptilde == 0,
   plotasblocks([xx 1],[PhiB; zeros(1,ptilde+nL-2)],greylineopt{:})
else
   plot([xx 1],[PhiB; zeros(1,ptilde+nL-2)],greylineopt{:})
end
hold on
plot(xx,PhiBref,lineopt{:})
plot(knots,zeros(size(knots)),knotopt{:})
plot(knots,diag(PhiBknots),knotopt{:})
% plot(knots(n)*[1 1],[0 1],lineopt{:})
plot(knots([1 nL]),[1 1],knotopt{:})
hold off
axis off
% axy = axis; axy(1:2) = [-0.05 1.1]; axy(4) = axy(4)*1.1; axis(axy)
axy = axis; axy(2) = 1.1; axy(4) = 1.2; axis(axy);
figpos = get(gcf,'position'); figpos(3:4) = figsize;
set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)
drawaxes
if makeepsfiles == true,
   fname = ['Bsplinebasis' num2str(ptilde) 'blackgrey.eps'];
   print('-depsc',fname);
end

if makeepsfiles == false,
   message1 = 'no eps file has been printed by makefigBsplinesptilde.';
   message2 = 'Set makeepsfiles = true; to print eps file.';
   disp([message1 message2])
end

