% This routine is called by makeplotschapter07.m

if exist('WTfamily') ~= 1, WTfamily = 'maxflat'; end
if exist('dualvanmom') ~= 1, dualvanmom = 2; end
if exist('primalvanmom') ~= 1, primalvanmom = dualvanmom; end
phiname = ['phi' WTfamily num2str(primalvanmom)];
psiname = ['psi' WTfamily num2str(primalvanmom)];
biortfamilies = {'CDF','cdf','CDFspline','cdfspline','spline','Bspline',...
                 'CDFLDL','CDFless'};
if ismember(WTfamily,biortfamilies),
   phiname = [phiname num2str(dualvanmom)];
   psiname = [psiname num2str(dualvanmom)];
end

forestgreen = [34 139 34]/255;
textopt = {'fontsize',14,'fontweight','bold'};
plotcolor = forestgreen;
if exist('makeepsbook') ~= 1, makeepsbook = false; end
if makeepsbook == true, plotcolor = [1 1 1]*0.3; end

if ismember(WTfamily,biortfamilies),
   [h, ht] = makeWTfilter(WTfamily,primalvanmom,dualvanmom);
   % remark: for the CDF-LDL family, the input consists of 1 necessary and 1
   % optional parameters. These parameters, although linked to the vanishing
   % moments, cannot just be identified as primalvanmom and dualvanmom. Hence
   % the names of the parameters does not quite reflect the meaning in the
   % CDF-LDL case, which we consider as a mere abuse of notation, without
   % further impact on the calculations. (In other words, when calling this
   % routine for CDF-LDL, the user should adopt the names
   % primalvanmom,dualvanmom, knowing that he/she means LDLpar and LDLvar)
else
   h = makeWTfilter(WTfamily,primalvanmom); ht = h;
end
h = h/sum(h)*2;
J = 10;
phiJ = dyadicrecursion2scaleeq(h,J);
s = length(h);
nJ = 2^J*(s-1);
xJ = 2^(-J)*(0:nJ);
plot(xJ,phiJ,'color',plotcolor,'linewidth',3)
axy = axis; axy(4) = axy(4)*1.1; axy(2) = s-1/2; axis(axy); axis off
drawaxes('xtick',(0:s-1),textopt{:})

if makeepsbook == true, 
   % Current matlab adds large white frame around plot, which may hide adjacent
   % text or plots when the eps is included in a tex file. The following lines
   % make the frame transparent.

   makefigtransparent

   print('-depsc',phiname),
end

ht = column(ht);
m = length(ht);
g = -ht(m:-1:1).*(-1).^(1:m)';
nJ1 = 2^J*(s+m-2);
PhiJ = zeros(nJ1,m);
for k = 0:m-1,
   PhiJ(1+2^J*k+(0:nJ),k+1) = column(phiJ);
end
xJ1 = 2^(-J-1)*(0:nJ1);
plot(xJ1,PhiJ*g,'color',plotcolor,'linewidth',3)
axy = axis; axy(4) = axy(4)*1.1; axy(2) = m-1/2; axis(axy); axis off
drawaxes('xtick',(0:m-1),textopt{:})

if makeepsbook == true,

   makefigtransparent

   print('-depsc',psiname),
end
