
% This routine can be used for comparing tensor product MLPT with tensor
% product CDF LDL RWT (nondecimated CDF wavelets with less dissimilar lengths, 
% that is).
% !! This is NOT the MLPT2D for scattered data
% see also ThreshLab/Tests/houseCDFLDL.m 

if exist('noisefree') ~= 1,
   noisefree = imread('~/Matlab/ThreshLab/Tests/TestImages/house.tif','tif');
   noisefree = double(noisefree);
end
if exist('nreslevels') ~= 1, nreslevels = 3; end
if exist('fname0') ~= 1, fname0 = ''; end
if exist('makeeps') ~= 1, makeeps = true; end
if exist('snrin') ~= 1, snrin = 3; end
if exist('realrandom') ~= 1, realrandom = false; end
greymap = [(0:255)' (0:255)' (0:255)']/255;
image(noisefree)
colormap(greymap)

if exist('noise1') ~= 1,
   if realrandom == false, randn('state',0); end
   whitenoise = randn(size(noisefree));

   noise1 = whitenoise;
   noise1 = double(noise1);
   noise1 = noise1 - mean2(noise1);
   ratio1 = snr2(noisefree,noise1);
   factor = 10^((ratio1 - snrin)/20);
   noise1 = noise1*factor;
   ratio1 = snr2(noisefree,noise1);
end

input = noisefree+noise1;
image(input);
colormap(greymap);

ptilde = 4; p = 4;
[h ht] = CDF_LDL(p,ptilde);
[h, g, ht, gt, sh, sg, sht, sgt] = mirrorshifts(h,ht);
M = nreslevels;
alfa = 0.5;

N = size(input,1);
wcoef = RWT2_BIO(input,M,ht,gt,sht,sgt);
vcoef = RWT2_BIO(noisefree,M,ht,gt,sht,sgt);
wout = wcoef;
label = zeros(size(wcoef));

for j = 1:M
j
  % horizontal component

  w = zeros(size(input));
  w(:,:) = wcoef(j,1,:,:);
  v = zeros(size(input));
  v(:,:) = vcoef(j,1,:,:);
  [wt, thr] = minmsethreshest(v,w,0);
  wout(j,1,:,:) = wt;
  label(j,1,:,:) = (abs(v) > thr);
  minmsethr(j,1) = thr;

  % diagonal subband

  w = zeros(size(input));
  w(:,:) = wcoef(j,2,:,:);
  v = zeros(size(input));
  v(:,:) = vcoef(j,2,:,:);
  [wt, thr] = minmsethreshest(v,w,0);
  wout(j,2,:,:) = wt;
  label(j,2,:,:) = (abs(v) > thr);
  minmsethr(j,2) = thr;

  % vertical subband

  w = zeros(size(input));
  w(:,:) = wcoef(j,3,:,:);
  v = zeros(size(input));
  v(:,:) = vcoef(j,3,:,:);
  [wt, thr] = minmsethreshest(v,w,0);
  wout(j,3,:,:) = wt;
  label(j,3,:,:) = (abs(v) > thr);
  minmsethr(j,3) = thr;

end
output = IRT2_BIO(wout,h,g,sh,sg,alfa);
image(output)


predkernel = 'cos';
if exist('finescalebandwidth') ~= 1, finescalebandwidth = 3; end
if exist('noprefilt') ~= 1, noprefilt = false; end
if exist('primmom') ~= 1, primmom = 2; end
Pmethod = 'extlocpolestimation00';
mlptpar = {'P',Pmethod,'convex',1,'prefiltoption','nomoments',...
           'kerneltype',predkernel,'bandwidth',finescalebandwidth,...
           'nt',2,'n',primmom,'Ht','idem'};
if noprefilt==true, mlptpar = mlptpar(1:end-2); end

y = input;
f = noisefree;
[Ne1 Ne2] = size(y);
wthr = cell(M,3);
for j = 1:M,
   % as x is taken to be [1 2 3 .... Ne] in every step, keeping the bandwidth
   % the same at all levels actually corresponds to doubling the bandwidth in
   % terms of the original grid

   x = (1:Ne1);
   xx{j,1} = x;
   [wcoef Ne1] = FMLPT1D(x,y,1,mlptpar{:});
   vcoef = FMLPT1D(x,f,1,mlptpar{:});
   x = (1:Ne2);
   xx{j,2} = x;
   [wcoef Ne2] = FMLPT1D(x,wcoef',1,mlptpar{:});
   wcoef = wcoef';
   vcoef = FMLPT1D(x,vcoef',1,mlptpar{:})';
   y = wcoef(1:Ne1,1:Ne2);
   f = vcoef(1:Ne1,1:Ne2);

   [Nw1 Nw2] = size(wcoef);

   % horizontal component

   w = wcoef(Ne1+1:Nw1,1:Ne2);
   v = vcoef(Ne1+1:Nw1,1:Ne2);
   [wt, thr] = minmsethreshest(v,w,0);
   wthr{j,1} = wt;
   minmsethr(j,1) = thr;

   % diagonal subband

   w = wcoef(Ne1+1:Nw1,Ne2+1:Nw2);
   v = vcoef(Ne1+1:Nw1,Ne2+1:Nw2);
   [wt, thr] = minmsethreshest(v,w,0);
   wthr{j,2} = wt;
   minmsethr(j,2) = thr;

   % vertical subband

   w = wcoef(1:Ne1,Ne2+1:Nw2);
   v = vcoef(1:Ne1,Ne2+1:Nw2);
   [wt, thr] = minmsethreshest(v,w,0);
   wthr{j,3} = wt;
   minmsethr(j,3) = thr;

end

ythr = y;
for j=M:-1:1,

  x1 = xx{j,1}; x2 = xx{j,2};
  ythr = [ythr wthr{j,3}; wthr{j,1} wthr{j,2}];
  ythr = IMLPT1D(x2,ythr',1,mlptpar{:})';
  ythr = IMLPT1D(x1,ythr,1,mlptpar{:});

end

% coarse scale basis functions
if exist('makeplotsbasisfunctions') ~= 1, makeplotsbasisfunctions = false; end
if makeplotsbasisfunctions == true,
   [n c] = max([length(xx{1,1}) length(xx{1,2})]);
   x = xx{1,c};
   [o nL] = FMLPT1D(x,zeros(size(x)),M,mlptpar{:});
   nw = length(o);
   I = zeros(nw,nL); I(1:nL,1:nL) = eye(nL);
   PhiL = IMLPT1D(x,I,M,mlptpar{:});
   Psi = IMLPT1D(x,eye(nw),M,mlptpar{:});
   Psi = Psi(1:n,nL+1:nw);
   PhiLbis = I(1:nL,1:nL);
   w = I(nL+1:nw,1:nL);
   nj1 = nL;
   for j=M:-1:1,
j
     nj = nj1; xj = xx{j,c}; nj1 = length(xj);
     wj = [PhiLbis; w(nj+(1:nj1),1:nL)];
     PhiLbis(1:nj1,1:nL) = IMLPT1D(xj,wj,1,mlptpar{:});
   end

   figure(2)
   plot(x,PhiLbis(:,1:10),'-','color',[1 1 1]*0.7,'linewidth',3)
   hold on
   plot(x,PhiL(:,1:10),'k-')
   plot(x,PhiL(:,1:10),'ko','markerfacecolor','k')
   hold off
   axis([1,40,0,1])
   axis off
   
end


snrIN = snr2(noisefree,input-noisefree)
snrCDFLDL = snr2(noisefree,output-noisefree)
snrMLPT = snr2(noisefree,ythr-noisefree)

figure(1)
image(input)
axis equal
axis off
if makeeps == true,
   makefigtransparent
   fnameout = ['observedimage' fname0 '.eps'];
   print(gcf,fnameout,'-depsc2');
else
   disp('press any key (1)')
   pause
end

image(output)
axis equal
axis off
if makeeps == true,
   makefigtransparent
   fnameout = ['denoisedimage' fname0 'RWTLDL.eps'];
   print(gcf,fnameout,'-depsc2');
else
   disp('press any key (2)')
   pause
end

image(ythr)
axis equal
axis off
if makeeps == true,
   makefigtransparent
   fnameout = ['denoisedimage' fname0 'MLPT.eps'];
   print(gcf,fnameout,'-depsc2');
end
