
% Makes Figures 9.4, 9.5, 9.6

fontopt = {'fontsize',14,'fontweight','bold'};
knotopt = {'ko','markersize',12,'markerfacecolor','k'};
if exist('makeeps') ~= 1, makeeps = false; end


n = 4098;
x = makegrid(n,0);

ff = zeros(6,n);

x0 = 0.345;
i = find(x<x0);
a = -0.4;
ff(1,i) = x(i).*(x0-x(i)).^a;
i = find(x>x0);
a = -0.35;
ff(1,i) = (x(i)-x0).^a;

ff(2,1:n) = makesignal(x,'bumps');
ff(3,1:n) = makesignal(x,'blocks');
ff(4,1:n) = makesignal(x,'heavisine');
ff(5,1:n) = cos(1./(x-x0));
ff(6,1:n) = abs(cos(exp(3*x)));
x0 = [0 0.2 0.4 0.65 0.87 1];
Phi = Bsplinebasis(x,x0,3);
ff(7,1:n) = Phi(1:n,4)';
axy = [0 1  0 4
       0 1  0 5
       0 1 -2 6
       0 1 -6 4
       0 1 -1 1
       0 1  0 1
       0 1  0 1];


M = 100;
log2smax = -5;
log2smin = -12;
log2s = (0:M-1)/(M-1)*log2smin + (M-1:-1:0)/(M-1)*log2smax;
s = 2.^log2s;
log2sticks = (log2smax:-1:log2smin);
log2spix = (log2sticks-log2sticks(1))/(log2sticks(end)-log2sticks(1))*(M-1)+1;
sticks = {log2spix(2:end),'yticklabel',log2sticks(2:end)};
testsigname = ...
     {'onebump','bumps','blocks','heavisine','cos1overx','abscosexp','spline'};


for c = 1:7,
   f = ff(c,1:n);
   d = simpleCWT(x,f,'mexicanhat',s);
   % d = simpleCWT(x,f,'derivgauss',s);
   dmax = max(max(abs(d)));
   k = 0.7;
   imd = -sign(d).*abs(d/dmax).^k*127.5+127.5;

   figure(1)
   plot(x,f,'linewidth',3,'color','k')
   axyc = axy(c,1:4); 
   yticks = bestticks(axyc(3),axyc(4),7);
   yticks = setdiff(yticks,0);
   axyc([2 4]) = axyc([2 4])*1.1; 
   if c<5, axyc(1) = -0.09; end
   axis(axyc)
   axis off
   drawaxes('xtick',[0 1],'ytick',yticks,fontopt{:})
   if makeeps == true,
      makefigtransparent
      fname = [testsigname{c} '.eps'];
      print('-deps',fname);
   end

   figure(2)
   image(imd)
   set(gca,'YDir','normal')
   colormap grey
   axyc = axis; axyc([2 4]) = axyc([2 4])*1.1; axis(axyc)
   axis off
   drawaxes('xtick',[0 n],'xticklabel',[0 1],'ytick',sticks{:},fontopt{:})
   if makeeps == true,
      makefigtransparent
      fname = ['CWT' testsigname{c} '.eps'];
      print('-deps',fname);
   end
   if makeeps == false,
      txt = ['press any key to proceed to test' num2str(c+1)'];
      disp(txt)
      pause
   end
   disp('----------------------------------------------------------')
end

plot(x,d,'k')
hold on
plot(x0,zeros(size(x0)),knotopt{:})
hold off
