% Makes Figures 12.5 and 12.6

if exist('makeeps') ~= 1, makeeps = false; end
fontsize = 18;
fontopt = {'fontsize',fontsize,'fontweight','bold'};
grey = [1 1 1]*0.5;
n = 2000;
p = 0.05;
randn('state',20); rand('state',20);
beta = setupsimulationYisKbetaplussigmaZ('eye',n,n,p,Inf,1);
stdev = 1;
errors = randn(size(beta))*stdev;
Y = beta+errors;
nlambda = 1000;
lambdamax = sqrt(2*log(n))*stdev;
lambda = (0:nlambda)/nlambda * lambdamax;
PE = softrisk(lambda,beta,stdev);
mse = MSE1thresh(beta,Y,lambda,1);
Deltap = SURE1soft(Y,lambda,stdev);
gcvhat = GCV1soft(Y,lambda);
Ekappahat = zeros(size(gcvhat));
kappahat = zeros(size(gcvhat));

for i = 1:nlambda,
   kappahat(i) = sum(abs(Y)>lambda(i));
   Ekappahat(i) = sum(1-cumgauss(lambda(i)-beta,stdev)+...
                      cumgauss(-lambda(i)-beta,stdev));
end
nulambda = Ekappahat;
gcvnulambda = gcvhat.*(1-kappahat/n).^2./(1-nulambda/n).^2;

plot(lambda,PE,':','color',grey,'linewidth',6)
hold on
plot(lambda,Deltap,'color','k','linewidth',3)
plot(lambda,PE+stdev^2,':','color',grey,'linewidth',6)
aa = axis; aa(4) = (aa(4)-aa(3))*1.1+aa(3); aa(2) = lambdamax*1.05;
plot(lambda,gcvnulambda,'color','k','linewidth',4)
plot(lambda,gcvhat,'color','k','linewidth',2)
hold off
axis(aa)

% legend('PE','\Delta_p','PE + \sigma^2','GCV','Position','E')
% set(gca,'fontsize',fontsize,'fontweight','bold')

% figsize = [1280 420];
figsize = [840 420]; papersize = figsize/96; figpaperpos = [0 0 papersize];
figpos = get(gcf,'position'); figpos(3:4) = figsize;
set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)

lambdaticks = bestticks(0,lambdamax,6);
drawaxes('xticks',lambdaticks,fontopt{:})
axis off
text(lambdamax*0.95,aa(3)*0.95+aa(4)*0.05,'\lambda',fontopt{:},...
     'HorizontalAlignment','right')

text(lambdamax,PE(nlambda)*1.25,'PE',fontopt{:},...
     'color',grey,'HorizontalAlignment','right')
text(lambdamax,PE(nlambda)*0.60,'\Delta_p',fontopt{:},...
     'color','k','HorizontalAlignment','right')
text(lambdamax,stdev^2+PE(nlambda)*0.60,'PE+\sigma^2',fontopt{:},...
     'color',grey,'HorizontalAlignment','right')
text(lambdamax,stdev^2+PE(nlambda)*1.25,'GCV',fontopt{:},...
     'color','k','HorizontalAlignment','right')
text(lambdamax,stdev^2+PE(nlambda)*1.65,'$$\widehat{\mathrm{GCV}}$$',fontopt{:},...
     'color','k','interpreter','LaTeX','HorizontalAlignment','right')

h = 1.1;
text(lambdamax,aa(3)*h+aa(4)*(1-h),'small models',fontopt{:},...
     'HorizontalAlignment','right')
text(lambda(1),aa(3)*h+aa(4)*(1-h),'large models',fontopt{:})

if makeeps==true,
   makefigtransparent
   print -depsc PECpGCV5pct.eps
else
   disp('Press any key to continue (1/2)')
   pause
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% cfr: illustratemirroreffect.m

lambdamax = max(abs(Y));
lambda = (0:nlambda)/nlambda * lambdamax;
for i = 1:nlambda,
   Ekappahat(i) = sum(1-cumgauss(lambda(i)-beta,stdev)+...
                      cumgauss(-lambda(i)-beta,stdev));
end
kappa = (1:n);
lambda = polyline(kappa,Ekappahat,lambda);

PEHT = hardrisk(lambda,beta,stdev);
PEST = softrisk(lambda,beta,stdev);

plot(lambda,PEHT,'color','k','linewidth',3)
hold on
plot(lambda,PEST,'color',grey,'linewidth',3)
hold off

axy = axis;

lambdamax = max(lambda);
axy(1:2) = [-1/10,1]*lambdamax;

axis(axy)
lambda1 = 0.6*lambdamax;
i1 = max(find(lambda>lambda1)); % max, as lambda is decreasing
text(lambda1,PEHT(i1)*0.90,'HT','color','k',fontopt{:})
text(lambda1,PEST(i1)*1.10,'ST','color',grey,fontopt{:})

% set(gcf,'position',[0 0 1400 500])
axis off
lambdaticks = bestticks(0,lambdamax,6);
PEticks = bestticks(0,max(PEST),6); PEticks = PEticks(2:end);
figsize = [560 420]; papersize = figsize/96; figpaperpos = [0 0 papersize];
figpos = get(gcf,'position'); figpos(3:4) = figsize;
set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)


drawaxes('linewidth',2,'xticks',lambdaticks,'yticks',PEticks,fontopt{1:4})

Dx = axy(2)-axy(1);
Dy = axy(4)-axy(3);

% cfr: http://www.mathworks.nl/help/matlab/ref/text_props.html
text(axy(2),Dy/20,'threshold value \lambda','HorizontalAlignment','right',fontopt{:})
text(Dx/20,axy(4)*0.95+axy(3)*0.05,'PE(\lambda)',fontopt{:})

if makeeps == true,
   makefigtransparent
   print -depsc PEfunctionofthr.eps
else
   disp('Press any key to continue (2/2)')
   pause
end


plot(kappa,PEHT,'color','k','linewidth',3)
hold on
plot(kappa,PEST,'color',grey,'linewidth',3)
hold off

axy = axis;
axy(1:2) = [-1/10,1]*n;

axis(axy)
kappao = round(0.6*n);
text(kappao,PEHT(kappao)*1.15,'HT','color','k',fontopt{:})
text(kappao,PEST(kappao)*0.75,'ST','color',grey,fontopt{:})

% set(gcf,'position',[0 0 1400 500])
axis off
kappaticks = bestticks(0,n,6);
drawaxes('linewidth',2,'xticks',kappaticks,'yticks',PEticks,fontopt{1:4})

Dx = axy(2)-axy(1);
Dy = axy(4)-axy(3);

% cfr: http://www.mathworks.nl/help/matlab/ref/text_props.html
text(axy(2),Dy/20,'Model size \kappa','HorizontalAlignment','right',fontopt{:})
text(Dx/20,axy(4)*0.95+axy(3)*0.05,'PE(\kappa)',fontopt{:})

if makeeps == true,
   makefigtransparent
   print -depsc PEfunctionofmodelsize.eps
else
   disp('No eps printed by makefigPECpGCV. Set makeeps=true; to print eps')
end

