% Makes Figure 11.8

if exist('makeeps') ~= 1, makeeps = false; end
if exist('makepdf') ~= 1, makepdf = false; end
if exist('dualmom') ~= 1, dualmom = 4; end
if exist('primmom') ~= 1, primmom = 2; end
% Current version of RWT_2Gspline.m (ThreshLab, version 4.5.2) has no
% implementation for primmom = [p nu-p] !!!
M = 1;
n = 64;
gridnumber = 1;
randomgrid = false; 
%%%%%%%%%%%%%%%%%% Parameters of plots %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fontsize = 14;
plotspecs = {'linewidth',2,'markerfacecolor','w','markersize',7};
bf = {'fontsize',fontsize,'fontweight','bold'};
bfit = {bf{:},'fontangle','italic'};
% mm = {'o','d','^','v','s'};
figsize = [840 420]; papersize = figsize/96; figpaperpos = [0 0 papersize];

%%%%%%%%%%%%%%%%%%% Parameters of MLPT refinement %%%%%%%%%%%%%%%%%%%%%%
% cfr. makefigMLPTbasis.m
if exist('ptmlpt') ~= 1, ptmlpt = 2; end
% bandwidth h0 has crucial impact on the shape of the basis functions. Check
% for instance h0 = 0.4; (Note that in the example in the help of
% refinescalingfunctionsMLPT, the number of knots is higher, so h0 here should
% be larger than there)
if exist('h0') ~= 1, h0 = 0.015*[1 2 4]; end % in proportion to nL
if exist('nreslevels') ~= 1, nreslevels = 3; end
% In wavelet refinement, the number of resolution levels is fixed by the number
% of knots at the finest scales, because wavelet refinement is dyadic.
% Since MLPT refinement is not necessarily dyadic, nreslevels is free to
% choose.
Pmethod = 'extlocpolestimation00';
kerneltype = 'cos'; % help evalkernel for other options
hh = NaN;
MLPTpar = {M,'P',Pmethod,'kerneltype',kerneltype,'nt',ptmlpt,'bandwidth',hh,...
                'convex',true};
if exist('moreMLPTpar'), MLPTpar = {MLPTpar{:},moreMLPTpar{:}}; end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
nh = length(h0);
sigmaPL = zeros(nh,n);
for h=1:nh,
   hJ = h0(h)/2^M; MLPTpar{9} = hJ;
   I = eye(n);
   x = makegrid(n,gridnumber,randomgrid)';
   [Wt, nL] = FMLPT1D(x,I,M,MLPTpar{:});
   nc = size(Wt,1);
   Ic = eye(nc);
   W = IMLPT1D(x,Ic,M,MLPTpar{:});

   VL = W(1:n,1:nL);
   VtL = Wt(1:nL,1:n);
   VtsemiorthL = (VL'*VL)\VL';
   PL = VL*VtL;
   PsemiorthL = VL*VtsemiorthL;

   [U, Ssemiorth, V] = svd(PsemiorthL); sigmaPsemiorthL = diag(Ssemiorth);
   [U, S, V] = svd(PL); sigmaPL(h,1:n) = diag(S);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1)
figpos = get(gcf,'position'); figpos(3:4) = figsize;
set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)

nL150 = ceil(3*nL/2);

p1 = plot(sigmaPsemiorthL(1:nL150),'ks-',plotspecs{:});
hold on
p2 = plot(sigmaPL(1,1:nL150),'k^-',plotspecs{:});
p3 = plot(sigmaPL(2,1:nL150),'kv-',plotspecs{:});
p4 = plot(sigmaPL(3,1:nL150),'ko-',plotspecs{:});
hold off

aa = axis;
aa(4) = floor(min(aa(4),max(10,sigmaPL(1))));
aa(2) = nL150 +5;
aa(4) = aa(4)+1;
aa(3) = aa(3)-(aa(4)-aa(3))/15;
axis(aa)
% title('SVD projections W*Wtilde',bf{:})
axis off
yticks = bestticks(aa(4));
drawaxes('ytick',yticks,'xtick',nL,'xticklabel',{'n_L'},bf{:})
ppp = [p1 p2 p3 p4];
legend(ppp,'semi-orth.','S bandwidth','M bandwidth','L bandwidth',bf{:})
% text(nL-0.5,aa(3),'n_L',bfit{:})
if makeeps==true,
   makefigtransparent
   print -depsc SVDprojMLPT.eps
end
if makepdf==true,
   makefigtransparent
   print -depsc SVDprojMLPT.pdf
end


normPLfrob = norm(PL,'fro')
normPLfrobis = norm(sigmaPL)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
MM = 4;
tt = (0:2^MM*(n-1))/(2^MM*(n-1));
t = (0:n-1)/(n-1);
xx = polyline(tt,t,x);
e = (1:n); for j=1:M, e = e(splitevenodd(e)); end; xL = x(e);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
MLPTsubdivpar = MLPTpar; MLPTsubdivpar{1} = M+MM;
for h=1:nh,
   hJ = h0(h)/2^M; MLPTsubdivpar{9} = hJ;
   PhiMLPT = refinescalingfunctionsMLPT(xx,xL,MLPTsubdivpar{:});
   figure(2)
   figpos = get(gcf,'position'); figpos(3:4) = figsize;
   set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)
   plot(xx,PhiMLPT,'k','linewidth',2)
   axis off
   axis([0 1.1 0 0.4])
   drawaxes('xtick',[0 1],bf{:})
   if makeeps==true,
      fname = ['MLPTbasisSVD' num2str(h) '.eps'];
      makefigtransparent
      print('-deps',fname);
   end
   if makepdf==true,
      fname = ['MLPTbasisSVD' num2str(h) '.eps'];
      makefigtransparent
      print('-dpdf',fname);
   end
   if makeeps==false & makepdf==false,
      disp(['plot ' num2str(h) ' out of ' num2str(nh)])
      pause
   end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if makeeps==false & makepdf==false,
   disp('no file has been printed. Set makepdf=true; or makeeps=true;')
end

