
function y = EiapprxBarry(x)

% EiapprxBarry -- Approximative Exponential Integral
%  Usage
%    y = EiapprxBarry(x)
%  Inputs
%    x   negative real matrix/vector/scalar
%  Outputs
%    y   matrix of the same size as x
%  Description
%    Approximate values for Exponential Integral
%  Note
%    https://en.wikipedia.org/wiki/Exponential_integral
%    valid for negative values of x only
%  See also:
%    help expint (built in specfun)

x = -x;
c = 0.57721566490153286060651209008240243104215933593992;
G = exp(-c);
b = sqrt(2*(1-G)/(2-G)/G);
a = (1-G)*(G^2-6*G+12)/(3*G*(2-G)^2*b);
q = 20/47*x.^sqrt(31/26);
h = 1./(1+x.*sqrt(x))+a*q./(1+q);
y = exp(-x)./(G+(1-G)*exp(-x/(1-G))).*log(1+G./x-(1-G)./(h+b*x).^2);
y = -y;
y(x<realmin) = -Inf;
y(x>750) = 0;

% Copyright (c) Maarten Jansen
%
% This software is part of ThreshLab and is copyrighted material. 

