
function AT = blocktranspose(A,b1,b2);

%  ThreshLab/General/blocktranspose -- transpose within each block of given size
%   Usage
%     AT = blocktranspose(A,b1,b2);
%     AT = blocktranspose(A,b);
%   Input
%     A   m x n matrix
%     b1  integer, number of rows in blocks
%     b2  integer, number of columns in blocks
%     b   pair of integers, (b1,b2)
%     b   integer, size of squared blocks, b1=b2=b; default b=gcd(m,n);
%         m and n must be multiples of b1 and b2 respectively
%   Output
%     AT  m x n matrix

[m n] = size(A); mn = m*n;
if nargin<2, b1 = gcd(m,n); end
if nargin<3, b2 = b1; end
if length(b1)>1, b2 = b1(2); b1 = b1(1); end
mb = floor(m/b1); nb = floor(n/b2);
if max(m-mb*b1,n-nb*b2)>0,
   error('matrix sizes must be multiples of block sizes')
end
mt = mb*b2; nt = nb*b1;
BR = orderpositions(m,n,b1,b2);
BRT = orderpositions(mt,nt,b2,b1,1);

aa = reshape(A,mn,1);
br = reshape(BR,mn,1); invbr = (1:mn)'; invbr(br) = (1:mn)';
aa = aa(invbr);
brt = reshape(BRT,mn,1); 
aat = aa(brt);
AT = reshape(aat,mt,nt);


function BR = orderpositions(m,n,b1,b2,row);

% This functions orders the elements according to the blocks, and by column
% or rows (if parameter row is nonzero) within each block

if nargin<5, row=0; end
mb = floor(m/b1); nb = floor(n/b2);
bb1 = floor((0:m-1)'/b1); bb2 = floor((0:n-1)/b2);
B = ones(m,1)*mb*bb2+bb1*ones(1,n);
% B has for each element the block number
rr1 = (0:m-1)'-bb1*b1; rr2 = (0:n-1)-bb2*b2;
if row==0,
   R = ones(m,1)*b1*rr2+rr1*ones(1,n)+1;
else
   R = ones(m,1)*rr2+rr1*ones(1,n)*b2+1;
end
% R has for each element the position within its block
BR = B*b1*b2+R;
