function betahat = constrLS(X,Y,A,c)

% constrLS -- least squares under constraints
%  Usage
%    betahat = constrLS(X,Y,A,c)
% Inputs
%    X     n x m real matrix
%    Y     n x k real matrix
%    A     q x m real matrix
%    c     q x 1 real vector
% Outputs
%    betahat m x k real matrix
% Description
%    finds betahat minimizing norm(X*beta-Y) 
%                  under the constraint that A*beta = c
% Note
%
% See Also
%          

[n m] = size(X);
[l k] = size(Y);
if l~=n, Y=Y'; l=k; if l~=n, error('dimension mismatch X and Y'), end, end
[l k] = size(Y);
if nargin<3, A = zeros(0,m); end
[q l] = size(A);
if l~=m, A=A'; l=q; if l~=m, error('dimension mismatch X and A'), end, end
[q l] = size(A);
if nargin<4, c = zeros(q,1); end
l = length(c); if l~=q, error('dimension mismatch A and c'), end
if n>0,
   betahat = pinv(X)*Y; XTX = X'*X; XTXAT = XTX\(A');
   if q>0, betahat = betahat+XTXAT*((A*XTXAT)\(c-A*betahat)); end
else
   betahat = pinv(A)*c;
end
