
function dates = day2date(date,days,format);

% day2date -- computes date number of days between given dates
%  Usage
%    dates = day2date(date,day,format);
%  Inputs
%    date     dates, numerical format yyyymmdd
%    days     vector of integers
%    format   char 'numeric','char' (default)
%  Outputs
%    dates    string of dates, format yyyy-mm-dd
%  Description
%    Finds the dates of a given number of days from initial date
%  Note
%    check dates = day2date(16981208,date2day([16981208 27880903]))
%  See also
%    help date2day

if nargin<3, format = 'char'; end
[n m] = size(days); days = reshape(days,1,n*m);
ndays = length(days);
day = round(frac(date/100)*100);
month = round(frac(floor(date/100)/100)*100);
year = round(date/10000);
days = day + days;
months = month + zeros(size(days));
years = year + zeros(size(days));
lastday = lastdayinmonth(months,years);
i = find(days>lastday);
while length(i)>0,
   days(i) = days(i)-lastday(i);
   years(i) = years(i)+floor(months(i)/12);
   months(i) = mod(months(i),12)+1;
   lastday = lastdayinmonth(months,years);
   i = find(days>lastday);
end
i = find(days<1);
while length(i)>0,
   months(i) = mod(months(i)-2,12)+1;
   years(i) = years(i)-floor(months(i)/12);
   lastday = lastdayinmonth(months,years);
   days(i) = days(i)+lastday(i);
   i = find(days<1);
end

switch format,
case {'num','numerical','numeric'},
   dates = 10000*years+100*months+days;
   dates = reshape(dates,n,m);
case {'char'},
   dates = char(ndays*11-1);
   dates(5+(0:ndays-1)*11) = '-';
   dates(8+(0:ndays-1)*11) = '-';
   dates(11*(1:ndays-1)) = sprintf('\n');
   for d = 1:ndays,
      dates((1:4)+(d-1)*11) = num2str(years(d));
      dates((6:7)+(d-1)*11) = num2str(months(d),'%02d');
      dates((9:10)+(d-1)*11) = num2str(days(d),'%02d');
   end
end


function lastday = lastdayinmonth(month,year)

daysinmonth = [31 28 31 30 31 30 31 31 30 31 30 31];
leapdaysinmonth = [0 1 0 0 0 0 0 0 0 0 0 0];
isleapyear = (mod(year,4)==0 & mod(year,100)~=0) | mod(year,400)==0;
lastday = daysinmonth(month)+leapdaysinmonth(month).*isleapyear;
