
function [x it] = linquadsystNR(A,b,c,L,r,x,maxit,tol);

% linquadsystNR -- solver for x'Ax+bx = c and Lx = r, using Newton-Raphson
%  Usage
%    [x it] = linquadsystNR(A,b,c,L,r,x,maxit,tol);
%  Inputs
%    A      squared matrix, let n = size(A,1);
%    b      row vector with length(b) = n
%    c      scalar
%    L      rectangular matrix: size(L) = (n-1) x n
%    r      column vector with length(r) = n-1
%    x      (optional) initial guess of x (vector of size n x 1)
%    maxit  integer, maximum number of iterations (default 10000)
%    tol    threshold on norm of increment in stopping criterion, default 1.e-8
%  Outputs
%    x      vector of size n x 1
%    it     integer, number of iterations used
%  Description
%  Note
%  See also

if nargin < 8, tol = 1.e-8; end
if nargin < 7, maxit = 10000; end
if nargin < 6, x = zeros(size(A,1),1); end

goon = true;
it = 0;
while goon==true,
   it = it+1;
   J = [x'*(A+A')+b; L];
   f = [x'*A*x+b*x-c; L*x-r];
   d = pinv(J)*(-f);
   x = x+d;
   if norm(d) < tol, goon = false; end
   if it>maxit, goon = false; end
end

