function [Q R it QQ] = minQTAplusBvec(A,B,W,maxit,maxjmini);

% minQTAplusB -- finds orthogonal Q that reduces norm(W.*(Q'*A+B),'fro')
%  Usage
%    [Q R it QQ] = minQTAplusBvec(A,B);
%    [Q R it QQ] = minQTAplusBvec(A,B,W);
%    [Q R it QQ] = minQTAplusBvec(A,B,maxit);
%    [Q R it QQ] = minQTAplusBvec(A,maxit);
%    [Q R it QQ] = minQTAplusBvec(A,B,maxit,maxjmini);
%  Inputs
%    A        rectangular or squared matrix; let [n m] = size(A)
%    B        matrix, size(A) = size(B), default B = zeros(size(A))
%    W        matrix, size(W) = size(A), default W = ones(size(A))
%    maxit    integer
%    maxjmini integer: maximum distance between two columns involved in a
%                      rotation or reflection
%  Outputs
%    Q      orthogonal matrix of size n x n, with n the # rows in A
%    R      R = Q'*A-B
%    it     number of iterations used
%    QQ     cell of matrices used in each iteration
%  Description
%    iterative application of minQTAplusBitvec.
%  Note
%  See also
%    help minQTAplusBitvec

types = 2;
tol = 1.e-4;
[n m] = size(A);
if nargin == 1, W = ones(size(A)); B = zeros(size(A)); maxit = 100; end
if nargin == 2,
   if max(size(B)) == 1,
      maxit = B; B = zeros(size(A)); W = ones(size(A));
   else
      W = ones(size(A)); maxit = 100;
   end
end
if nargin == 3,
   if max(size(W)) == 1,
      maxit = W; W = ones(size(A));
   else
      maxit = 100;
   end
end
if nargin < 5, maxjmini = ceil(n/2); end
if nargout > 3, makeQQ = true; else, makeQQ = false; end
if makeQQ, QQ = cell(1,maxit); end

it = 0;
froR = norm((A+B).*W,'fro');
froAplusB = froR+1;
Q = eye(size(A,1));
while froAplusB-froR > tol,
   it = it+1;
   froAplusB = froR;
   % if mod(it,2)==0, A = frwshift(A',1)'; B = frwshift(B',1)'; W = frwshift(W',1)'; end
   % shift to make sure that last row is rotated with rows on top (see remark
   % in minQTAplusBitvec)
   [Qit R P] = minQTAplusBitvec(A,B,W,types,maxjmini);
   froR = norm(R.*W,'fro');
   A=R-B;
   Q = Q*Qit;
   if it>maxit, froAplusB = froR; end
   if makeQQ, QQ{it} = Qit; end
end
if makeQQ, QQ = QQ(1:it); end
