
function [x iter r Q H] = minxAxminbxkrylov(A,b,varargin);

% minxAxminbxkrylov -- iterative procedure for minimisation of x'Ax-b'x
%  Usage
%     [x iter r Q H] = minxAxminbxkrylov(A,b,varargin);
%   Inputs
%     A            nxn matrix
%     b            nx1 vector
%   Optional Inputs
%     'maxit',maxit  maximum number of iterations (default n)
%     'itmax',maxit  (idem)
%     'x0',x0        initial value 
%     'start',x0
%     'init',x0
%     'initial',x0
%     'tol',tol      tolerance for stopping criterion (on residual)
%   Outputs
%     x            best approximnation of arg min(x'*A*x-b'*x), using a Krylov
%                  subspace method
%     iter         number of iterations used
%     r            residual
%     Q            orthogonal basis of Krylov subspace
%     H            
%   Description
%   Note
%   See also

n = size(A,2);
% default values
x0 = zeros(n,1);
maxit = n;
tol = 1.e-10;

nvarargin = length(varargin);
k = 1;
while k <= nvarargin, vark = varargin{k}; if ischar(vark), switch(vark)
   case {'maxit','itmax'}
      maxit = min(n,varargin{k+1});
      k = k+2;
   case {'x0','start','init','initial'}
      x0 = varargin{k+1};
      k = k+2;
   case {'tol'}
      tol = varargin{k+1};
      k = k+2;
   otherwise
      k = k+1;
end, end, end

e1 = zeros(maxit+1,1); e1(1) = 1;
beta = norm(b-A*x0);
betae1 = beta*e1;
qk = b;
hkk = norm(qk);
qk = qk/hkk;
Hkk = [];
Qk = qk; k = 1; iter = k;
while k < maxit+1
   qk = A*qk;
   hk = Qk'*qk;
   qk = qk-Qk*hk;
   hkk = norm(qk);
   if isnan(hkk) | hkk < eps,
      k = maxit+1;
   else,
      qk = qk/hkk;
      Qkk = [Qk qk];
      Hkk = [[Hkk; zeros(1,k-1)] [hk;hkk]];
      Hk = Hkk(1:k,1:k);
      uk = (Hk+Hk')\(2*Qk'*b);
      % uk = Hk\(Qk'*b);
      xk = Qk*uk;
      rk = A*xk-b;
      if norm(rk)<tol, 
         k = maxit+1;
      else
         k = k+1; iter = k; Qk = Qkk;
      end
   end
end
x = xk;
r = rk;

Q = Qk;
H = Hk;
