function [y, d] = uniquewithduplicates(x,tol);

% uniquewithduplicates - ThreshLab/General -- finds duplicates in real array
% Usage
%    [y, d] = uniquewithduplicates(x,tol);
% Inputs
%    x       vector/array of real numbers
%    tol     tolerance (optional; default = 1.e-6)
% Outputs
%    y       vector of unique elements in x, in order of first appearance
%    d       indices of length(x), so that x=y(d) (up to tolerance)
% Description

if nargin < 2, tol = 1.e-6; end
[xo o] = sort(x); n = length(x);
xoroundtol = round(xo/tol);
dd = 1+find(xoroundtol(1:n-1)==xoroundtol(2:n));
% dd contains positions of doubles in ordered vector
ndd = length(dd);
duplicate = (1:n);
if ndd>0,
   dd1 = o(dd-1); % dd1 contains positions of first occurrences in x
   dd2 = o(dd); % dd2 contains positions of second occurrences in x
   for d = 1:ndd, duplicate(dd2(d)) = duplicate(dd1(d)); end
   secondormoreappearances = sort(dd2);
   uniquepoints = find(duplicate==(1:n));
   for d = 1:ndd,
      % for every 2nd, 3rd, ... appearance, the position of all first
      % appearance of points not  appeared so far must be lowered by one
      i = find(duplicate>max(duplicate(1:secondormoreappearances(d))));
      duplicate(i) = duplicate(i) - 1;
   end
   y = x(uniquepoints);
else
   y = x;
end
d = duplicate;
