
function ans = make4Dgraph(x,y,z,t,varargin);

% make4Dgraph - ThreshLab/Plots -- 
%   Usage
%     make4Dgraph(x,y,z,t)
%     make4Dgraph(X)
%   Inputs
%     x,y,z,t  equally sized vectors
%     X        n x 4 sized matrix
%   Outputs
%     void
%   Description
%     makes 4D plot:
%     (x,y,z,t) is represented by disks in a 2D graph
%     x is displayed on the horizontal axis
%     y is displayed on the vertical axis
%     z is represented by the radius of the disks
%     t is represented by the grey level filling the disk


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if min(size(x)) > 1,
   if size(x,1) == 4, x = x'; end
   if size(x,2) == 4, 
      switch nargin,
         case 1, varargin = {};
         case 2, varargin = {y};
         case 3, varargin = {y,z};
         case 4, varargin = {y,z,t};
         otherwise, varargin = {y,z,t,varargin{:}};
      end
      n = size(x,1); t = x(1:n,4); z = x(1:n,3); y = x(1:n,2); x = x(1:n,1);
   end
end
n = length(x);
if length(y) ~= n, error('dimension mismatch y and x'); end
if length(z) ~= n, error('dimension mismatch z and x'); end
if length(t) ~= n, error('dimension mismatch t and x'); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

options = {};
ncolors = 0;
color0 = [1 1 1];
color1 = [0 0 0];
addxmean = false; addymean = false; addxmedian = false; addymedian = false;
forcexaxison0 = false; forceyaxison0 = false;
nvarargin = length(varargin);
a = 0;
while a < nvarargin, a=a+1; vara = varargin{a}; 
   if ischar(vara), switch(vara)
      case {'ncolors'},
         ncolors = varargin{a+1}; a = a+1;
      case {'color0'},
         color0 = varargin{a+1}; a = a+1;
      case {'color1'},
         color1 = varargin{a+1}; a = a+1;
      case {'addmean','addmeans'},
         addxmean = true; addymean = true;
      case {'addxmean'}, addxmean = true;
      case {'addymean'}, addymean = true;
      case {'addmedian','addmedians'},
         addxmedian = true; addymedian = true;
      case {'addxmedian'}, addxmedian = true;
      case {'addymedian'}, addymedian = true;
      case {'forceaxeson0'},
         forcexaxison0 = true; forceyaxison0 = true;
      case {'forcexaxison0'},
         forcexaxison0 = true;
      case {'forceyaxison0'},
         forceyaxison0 = true;
      otherwise
         options = {options{:},varargin{a}};
      end
   else
      options = {options{:},varargin{a}};
   end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


if ncolors == 0, ncolors = n; end
cc = ones(ncolors,1)*color0+column(0:ncolors-1)/(ncolors-1)*(color1-color0);

xmin = min(x); xmax = max(x); xrange = xmax-xmin;
xmin = xmin-xrange/10;
xlabels = findaxislabels([xmin xmax]);
if forceyaxison0 == true & xmin*xmax<0,
   u = x/(xmax-xmin); ulabels = xlabels/(xmax-xmin);
else
   u = (x-xmin)/(xmax-xmin); ulabels = (xlabels-xmin)/(xmax-xmin);
end

ymin = min(y); ymax = max(y); yrange = ymax-ymin;
ymin = ymin-yrange/10; 
ylabels = findaxislabels([ymin ymax]);
if forcexaxison0 == true & ymin*ymax<0,
   v = y/(ymax-ymin); vlabels = ylabels/(ymax-ymin);
else
   v = (y-ymin)/(ymax-ymin); vlabels = (ylabels-ymin)/(ymax-ymin);
end

zmin = min(z); zmax = max(z);
r = (z-zmin)/(zmax-zmin);
r = 1.5*(r.^4+1)/n;

tmin = min(t); tmax = max(t);
c = max(1,ceil((t-tmin)/(tmax-tmin)*ncolors));

for i=1:n,
   plotascircles(u(i),v(i),r(i),'fill',cc(c(i),1:3),'linewidth',2,'color','k');
   hold on
end
hold off
axis equal
axis off
xaxoptions = {'xtick',ulabels,'xticklabel',xlabels};
yaxoptions = {'ytick',vlabels,'yticklabel',ylabels};
textoptions = {'fontsize',14,'fontweight','b'};
drawaxes(xaxoptions{:},yaxoptions{:},textoptions{:})

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

axy = axis;
hold on
if addxmean == true, 
   uu = mean(u); plot(uu*[1 1],axy(3:4),'--','color','k','linewidth',3)
   % xx = mean(x); uu = min(u)+(xx-xmin)/(xmax-xmin);
end
if addxmedian == true, 
   uu = median(u); plot(uu*[1 1],axy(3:4),'--','color','k','linewidth',3)
end
if addymean == true, 
   vv = mean(v); plot(axy(1:2),vv*[1 1],'--','color','k','linewidth',3)
end
if addymedian == true,
   vv = median(v); plot(axy(1:2),vv*[1 1],'--','color','k','linewidth',3)
end
hold off



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function xlabels = findaxislabels(x,maxnlabels)

if nargin < 2, maxnlabels = 8; end
xmin = min(x); xmax = max(x); xrange = xmax-xmin; dxmin = xrange/maxnlabels;
dxminndigits = floor(log10(dxmin));
dxmin1stdigit = ceil(dxmin/10^dxminndigits);
if dxmin1stdigit > 5, dxmin1stdigit = 10;
elseif dxmin1stdigit > 2, dxmin1stdigit = 5;
end
dxmin = dxmin1stdigit*10^dxminndigits;
xlabels = dxmin*(ceil(xmin/dxmin):floor(xmax/dxmin));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright (c) Maarten Jansen
%
% This software is part of ThreshLab and is copyrighted material.

