
function ans = plotascircles(x,y,r,varargin)

% plotascircles - ThreshLab/Plots -- plot z=f(x,y) as circles
%   Usage
%     plotascircles(x,y,z)
%     plotascircles(x,y,z,options)
%   Inputs
%     x,y     vectors of abscis values
%     z       vector of coordinate values z = f(x,y)
%     options plot options, as in matlab command plot
%             additional option 'fill',fillcolor
%     fillcolor triple of numbers in [0,1]
%   Outputs
%     none
%   Description
%     plot circles with radii proportional to values in z and centers in (x,y)
%   See also
%     help plotasspikes
%     help plotasblocks

dofill = false;
if nargin < 3,
   error('Not enough input arguments.')
elseif nargin == 3,
   options = {'b'};
else
   options = {};
   nvarargin = length(varargin);
   a = 0;
   while a < nvarargin, a=a+1; vara = varargin{a};
      if ischar(vara), 
         switch(vara)
         case {'fill','fillcolor'},
            fillcolor = varargin{a+1}; a = a+1;
            dofill = true;
         otherwise
            options = {options{:},varargin{a}};
         end
      else
         options = {options{:},varargin{a}};
      end
   end
end

if length(r) == 1, r = r*ones(size(x)); end
h = ishold;
N = length(x);
m = 50;
t = (0:m)/m*2*pi;
for i = 1:N,
   u = x(i) + cos(t) * r(i);
   v = y(i) + sin(t) * r(i);
   if dofill == true, fill(u,v,fillcolor); hold on, end
   plot(u,v,options{:});
   hold on
end
if ~h, hold off, end
ans = 1;

% Copyright (c) Maarten Jansen
%
% This software is part of ThreshLab and is copyrighted material.

