
function levelborders = plotresolutionlevels(w,varargin);

% plotresolutionlevels - ThreshLab/Plots -- plot wavelet coefficients and
%                                           borders resolutionlevels
%   Usage
%     plotresolutionlevels(w,L,wmin,wmax)
%     plotresolutionlevels(w,L)
%     plotresolutionlevels(w,L,wmin,wmax,option)
%     plotresolutionlevels(w,L,option)
%     plotresolutionlevels(w,levelborders,...)
%   Inputs
%     w      sequence of wavelet coefficients
%     L      lowest scale
%     wmin   lower bound on y-axis of plot
%     wmax   upper bound on y-axis of plot
%     option plot options, as in matlab command plot
%   Outputs
%     void
%   Description
%     plots wavelet coefficients in w, with dashed lines indicating boundaries
%     between resolution levels

n = length(w); J = ceil(log2(n));
L = 0; wmin = NaN; wmax = NaN;
levelborders = NaN;
fillup = false;
BW = true;
nvarargin = length(varargin)+1;
varargin = {varargin{:},'stop'}; % sentinel
k = 1; vark = varargin{1};
while ~ischar(vark),
   switch(size(vark,1)*size(vark,2)),
   case 1,
      if vark==floor(vark) & vark<J & L==0 & vark>-1, L = vark;
      elseif isnan(wmin), wmin = vark;
      elseif isnan(wmax), wmax = vark;
      end
   case 2,
      wmin = min(vark); wmax = max(vark);
   otherwise
      if all(vark==floor(vark)), levelborders = vark; end
   end
   k=k+1; vark = varargin{k};
end
plotoptions = {};
while k<nvarargin,
   if ischar(vark), switch(vark),
   case {'fill'},
      fillup = true;
   case {'rgb','RGB','fillcolor'},
      BW = false; fillup = true;
   case {'fillgrey','fillgray','fillBW','fillbw'},
      BW = true; fillup = true;
   otherwise
      plotoptions = {plotoptions{:},vark};
   end
   else
      plotoptions = {plotoptions{:},vark};
   end
   k=k+1; vark = varargin{k};
end

h = ishold;
if any(isnan(levelborders)),
   M = J-L; 
   if M>0,
      levelborders = zeros(1,M+1); levelborders(M+1) = n;
      e = (1:n);
      for j=M:-1:1, e = e(splitevenodd(e)); levelborders(j) = length(e); end
   else % no multilevel decomposition => single level
      levelborders = 0;
   end
else,
   M = length(levelborders); L = J-M;
end
nL = levelborders(1);
if isnan(wmax), wmax = max(abs(w(nL+1:n))); end
if isnan(wmin), wmin = -wmax; end
vert = [wmin,wmax];
if fillup==false,
   plotasspikes(w,plotoptions{:})
   hold on
   for j = 1:M
      levelborder = levelborders(j)*[1 1];
      plot(levelborder,vert,'k--','linewidth',2)
   end
   hold off
else,
   jM = (1-column((M:-1:1)/M).^2)*0.95;
   if BW, 
      colord = jM*[1 1 1]; colors = [1 1 1]/2;
   else
      colord = [ones(M,1) jM zeros(M,1)]; colors = [0.5 0.5 1];
   end
   fill(0.5+[-0.5 levelborders([M M]) 0],[wmin wmin wmax wmax],colors)
   hold on
   for j = M:-1:1,
      fill(0.5+levelborders(j+[0 1 1 0]),[wmin wmin wmax wmax],colord(j,1:3))
   end
   plotasspikes(w,plotoptions{:})
   hold off
end

axis([0,n,wmin,wmax])
if ~h, hold off, end

if nargout<1, clear levelborders; end

% Copyright (c) Maarten Jansen
% 
% This software is part of ThreshLab and is copyrighted material. 
