
function f = integralbumpjumpkink(x);

% ThreshLab/Tests/integralbumpjumpkink -- creates integral of bumpjumpkink 
%                                         testfunction
%  Usage
%    f = integralbumpjumpkink(x);
%    f = integralbumpjumpkink(N);
%  Inputs
%    x      abscis value (possibly (non-)equidistant)
%    N      number of equidistant abscis values (1:N)/N
%  Outputs
%    f      function values of bumpjumpkink testfunction in x or (1:N)/N
%  Description
%    evaluates bumps testfunction in t = (x - x(1))/(x(N)-x(1))
%  See also
%    help blocks
%    help doppler
%    help heavisine
%    help skyline
%    help bumpjumpkink
%    help derivativebumpjumpkink

N = length(x);
if N == 1 & x(1)>1,
   N = x;
   x = (1:N);
end
if N>1,
   t = (x - x(1))/(x(N) - x(1));
elseif 0<=x & x<= 1,
   t = x;
end

c = [0 0.3 0.4 0.62 0.7 0.85 Inf];
I = length(c)-1;
i = cell(I,1);

for k = 1:I,
   i{k} = find(t>=c(k) &  t<c(k+1));
end

f = zeros(size(t));
I0 = 1/9;
f(i{1}) = I0-cos(9*t(i{1}))/9;
I1 = I0-cos(9*c(2))/9;
f(i{2}) = I1+4*(t(i{2})-c(2));
I2 = I1+4*(c(3)-c(2));
t3 = t(i{3}); n3 = length(t3); 
if n3>0,
   t0 = c(3); t1 = c(4);
   f(i{3}) = I2+4/3*(t3-t1).^3/(t0-t1)^2-4/3*(t0-t1);
end
I3 = I2+4/3*(c(4)-t1)^3/(t0-t1)^2-4/3*(t0-t1);
t4 = t(i{4}); n4 = length(t4); 
if n4>0,
   t0 = c(4); t1 = c(5); r = t1-t0; t4 = t4-t0;
   f(i{4}) = I3+8*(t4-r*asin(t4/r)/2-(t4/2).*sqrt(1-t4.^2/r^2));
end
% I4 = I3+8*(c(5)-r*asin(c(5)/r)/2-(c(5)/2).*sqrt(1-c(5).^2/r^2));
I4 = I3+8*(r-r*pi/4);
t5 = t(i{5}); n5 = length(t5);
if n5>0, 
   t0 = c(5); t1 = c(6); r = t1-t0; t5 = t1-t5;
   f(i{5}) = I4-8*(r*pi/4-r+t5-r*asin(t5/r)/2-(t5/2).*sqrt(1-t5.^2/r^2));
end
I5 = I4-8*(r*pi/4-r);
t6 = t(i{6}); n6 = length(t6);
if n6>0,
   t6 = t6-t6(1); f(i{6}) = I5+2*t6+9*t6.^2/2;
end
