
function f = makesignal(x,signalID)

% makesignal -- ThreshLab/Tests/
%  Usage
%    f = makesignal(x,signalID);
%    f = makesignal(N,signalID);
%  Inputs
%    x        real vector
%    N        integer, size of equidistant vector (1:N)/N
%    signalID integer or string, number or name of testfunction 
%  Outputs
%  Description
%    available signalID's include:
%      'heavisine','heavysine','block(s)','bump(s)','doppler','skyline'
%  Note
%  See also
%    help makegrid


N = length(x);
if N == 1,
   N = x;
   x = (1:N)/N;
end

if ischar(signalID), signalID = [signalID '    ']; switch signalID(2:4),
   case 'eav',
      f = heavisine(x);
   case 'loc',
      f = blocks(x);
   case 'ump',
      signalID2 = [signalID '      '];
      switch signalID2(5:6)
      case 's ',
         f = bumps(x);
      case 'ju',
         f = bumpjumpkink(x);
      end
   case 'opp',
      f = doppler(x);
   case {'ne ','nes'},
      f = ones(size(x));
   otherwise
      f = skyline(x);
   end
elseif isnumeric(signalID), switch signalID,
case 0,
   f = zeros(size(x));
case 1,
   f = ones(size(x));
case 2,
   f = sin(3*pi*x/4);
case 3,
   f = skyline(x);
case 4,
   % Donoho's heavy sine 
   f = 4.*sin(4*pi.*x);
   f = f - sign(x - .3) - sign(.72 - x);
case 401,
   % Donoho's heavy sine on [0,1]
   t = (x - x(1))/(x(N) - x(1));
   f = 4.*sin(4*pi.*t);
   f = f - sign(t - .3) - sign(.72 - t);
case 5,
   f = sin(4*pi.*x).*exp(-x);
case 51,
   f = sin(4*pi.*x).*exp(-x);
   f = f + (x>0.3) - (x>0.7)*0.3;
case 6,
   f = sin(12.*x).*exp(-x);
case 61,
   f = sin(4*pi.*x).*exp(-x);
   f = f + (x>0.3) - (x>0.7)*0.3;
otherwise
   f = ones(size(x));
end, end
