function f = matterhornpdf(x,s);

% ThreshLab/Noise/matterhornpdf -- Matterhorn probablity density function 
%    Usage
%      f = matterhornpdf(x,s);
%    Inputs
%      x    vector or scalar
%      s    parameter vector (of size(x) if size(x)>1) or scalar
%    Outputs
%      f    vector of size(x) and/or size(s)
%    Description
%      f = 1/{|t| [log(|t|)]^2} for -1/e^2<t<1/e^2, where t = x/s
%    Note
%      X ~ matterhorn if X = S*exp(-2/U), with P(S=-1)=1/2=P(S=1)
%                                          and U ~ unif[0,1]

e = exp(1);
if nargin<2, s = e^2; end
t = x/s;
f = 1./(abs(t).*(log(abs(t))).^2)/s;
f(abs(t)>1/e^2)=0;
f(abs(t)<eps) = Inf;

% Copyright (c) Maarten Jansen
% 
% This software is part of ThreshLab and is copyrighted material. 

