
function f = randblocks(x,nknots,p);

% ThreshLab/Tests/randblocks -- creates randomblocks testfunction
%  Usage
%    f = randblocks(x,nknots);
%    f = randblocks(N,nknots);
%  Inputs
%    x      abscis value (possibly (non-)equidistant)
%    N      number of equidistant abscis values (1:N)/N
%    nknots number of knots (jumps) -- default is 11 (as in blocks.m)
%    p      real number in [0,1]; probability that a jump is followed by jump
%           in the other direction (default is 0.9)
%  Outputs
%    f      function values of blocks testfunction in x or (1:N)/N
%  Description
%    evaluates a random blocks testfunction in t = (x - x(1))/(x(N)-x(1))
%  Note
%    randblocks calls (directly and indirectly) matlab's RAND function and 
%    therefore changes RAND's state.
%  See also
%    help blocks

N = length(x);
if N == 1 & x(1)>1,
   N = x;
   x = (1:N);
end
if N>1,
   t = (x - x(1))/(x(N) - x(1));
elseif 0<=x & x<= 1,
   t = x;
end

if nargin<2, nknots = 11; end
if nargin<3, p = 0.9; end

f = zeros(size(t));
if nknots > 0,
   % pos = sort(rand(1,nknots));
   pos = ((0:nknots-1)+rand(1,nknots))/nknots;
   hgt = rand(1,nknots);
   sgn = randMCbinary(nknots,p,p);
   for j=1:length(pos)
      f = f + double(t >= pos(j))*hgt(j)*sgn(j);
   end
end
f = f-mean(f);
