
function [f, d, h] = randsmoothfuncMLPT(x,varargin);

% randsmoothfunc -- ThreshLab2/Irregular/MultiscaleKernel -- 
%                   generates random smooth function from multiscale local
%                   polynomial decomposition
%  Usage
%    [f, d] = randsmoothfuncMLPT(x,varargin);
%  Inputs
%    x        grid-locations of observations (time, space)
%    varargin several options (see below)
%  Outputs
%    f        random smooth function on x
%    d        multiscale local polynomial decomposition of x, f = IMLPT1D(x,d)
%  Description
%  Examples
%  Notes
%    (1) f = IMLPT1D(x,d), but d =/= FMLPT1D(x,f), because the transform is
%        overcomplete and because it has a smoothing effect
%    (2) 
%    randsmoothfuncMLPT calls matlab's RANDN function and therefore changes 
%    RANDN's state.
%  See also
%    help IMLPT1D

n = length(x);
M = 5;
predkernel = 'cos';
pt = 2;
% K = 4;
% finescalebandwidth = K*(max(x)-min(x))*log(n)/(2*n); % heuristical choice
K = 3.5;
finescalebandwidth = K*(max(x)-min(x))*log(n)/n;
% K = 12;
% finescalebandwidth = K*(max(x)-min(x))/n;

nvarargin = length(varargin);
for k = 1:nvarargin, vark = varargin{k}; if ischar(vark), switch(vark)
    case {'pt','dualmom','dualmoments','ndual','ndualmoments'}
       pt = varargin{k+1};
    case {'finescalebandwidth','hJ','bandwidth'}
       finescalebandwidth = varargin{k+1};
end, end, end


hJ = finescalebandwidth;

decpar = {M,'P','locpol','kerneltype',predkernel,'bandwidth',hJ,'pt',pt};
decpar = {decpar{:},'logfactorbandwidth'};
[d Ne moments odds hulls h] = FMLPT1D(x,zeros(size(x)),decpar{:});

Nej = Ne;
d = zeros(size(d));
Ncj = Ne; % Ncj is # of coefficients at coarser scales than current
          % In critically downsampled transforms, Ncj equals Nej, but in the
          % MLPT, Ncj has to be computed seperately.
for j = 1:M-1,
   hj = h(j);
   Noj = length(odds{j});
   Ndj = Nej+Noj;
   d(Ncj+1:Ncj+Ndj) = randn(1,Ndj)*hj^pt;
   Nej = Ndj;
   Ncj = Ncj+Ndj;
end
f = IMLPT1D(x,d,decpar{:});
h = h(1:M);
