
% large simulation study as reported in
% Jansen (2007) Multiscale change point analysis in Poisson count data, 
% in: Chemometrics and Intelligent Laboratory Systems, 85(2), pages 159-169,
% Feb 2007.
%
% Every estimated change point should be linked to a real change point. A
% marriage between estimated and real can be concluded if both are closest to
% each other (as in real life).

% First set up underlying intension function
if ~exist('N'), N = 4096; end
x = (1:N);
f = blocks(x) + 3.5;

CPf = find(f(2:N)~=f(1:N-1))+1;
% CPf:  real change points
% two sentinel elements:
CPf = sort([1 CPf N+1]);
nCPf = length(CPf);

% Second, set up number of simulations and starting seed
realrandom = 1;
% realrandom=1 as argument in y = poissonnoise(f,realrandom); makes sure that every
% simulation run works with different y
if exist('usesavedseed') ~= 1, usesavedseed = 0; end
if usesavedseed,
   seed = load('seedsave')
else
   seed = 0
end
rand('state',seed)
if ~exist('nsimul'), nsimul = 200; end

% Third, set parameters of actual search-for-changepoints routine
m = 247;
% number of additional levels in discretized continuous wavelet transform
hhthh = makelinearwaveletfilter('coiflet',4,7);


% Now, run:

estimate = ones(nsimul,nCPf)*NaN;
estimate(:,1) = 1;
estimate(:,nCPf) = N+1;
pdfy = 'poisson';

for simul = 1:nsimul,
simul
   y = poissonnoise(f,realrandom);

   searchformultiplechangepoints

   CPff = sort(unique(breakpoints1(1:nCPdaic+2)));
                              % note that 1 and N+1 are default breakpoints
   numberofCPfound(simul) = nCP;

   [match1 match2] = matchpoints(CPf,CPff);
   i1 = find(~isnan(match1)); 
   estimate(simul,i1) = CPff(match1(i1));

fid = fopen('results_simulationstudyjansen07changepoint.m','w');
fprintf(fid,'estimate = [');
for i = 1:simul,
   fprintf(fid,'\n');
   fprintf(fid,'%d ',estimate(i,:));
end
fprintf(fid,'];\n');

fprintf(fid,'numberofCPfound = [');
fprintf(fid,'%d ',numberofCPfound(1:simul));
fprintf(fid,'];\n');

fprintf(fid,'realCPfound = sum(~isnan(estimate''))-2;');
fclose(fid);


end
for cp = 1:nCPf,
   plot(estimate(:,cp),(1:nsimul))
   hold on
   plot(estimate(:,cp),(1:nsimul),'*')
end
plot(f/max(f)*0.25*nsimul,'g')
hold off

seed = rand('state');
save 'seedsave' seed -ascii -double

