function [y yo] = frwliftingsteps(x,UP,e);

% frwliftingsteps - ThreshLab2/Irregular/1D/ --- forward filterbank transform
%                   using given lifting steps
% Usage
%   y = frwliftingsteps(x,UP);
%   y = frwliftingsteps(x,UP,e);
%   [ye yo] = frwliftingsteps(x,UP);
%   [ye yo] = frwliftingsteps(x,UP,e);
% Input
%   x     vector or matrix; fine scale coefficients
%   UP    cell array of matrices, corresponding to the lifting operations
%   e     (optional) integer vector; indices into x (default: e = (1:2:n))
% Output
%   y     vector or matrix, size of x
%   ye    vector or matrix
%   yo    vector or matrix
% Note
%   (1)
%   This routine is for use in critically downsampled decompositions
%   (2)
%   The current implemention assumes that the last lifting step is a rescaling
%   of the evens and the one but last step is a prediction of the odds.
%   (3)
%   The implementation slightly deviates from the paper on Nonequispaced
%   B-spline wavelets in the Theorem (wavelet transform from lifting
%   factoring). This implementation adopts the defintion P = H_{j,o} for
%   the final prediction step, while the paper uses P = H_{j,o}/D.
% Example
%   Wt = frwliftingsteps(eye(n),UP);
% See also
%   help invliftingsteps

nUP = length(UP)-1;
P0 = false; D1 = false;
if nUP>-1, D = UP{nUP+1}; else, D1 = true; end
if nUP>0, P = UP{nUP}; else, P0 = true; end
if P0==false,
   [no, ne] = size(P);
   n = ne+no;
   if nargin < 3, e = (1:2:n); end
   if length(e) ~= ne,
      error('dimension mismatch prediction matrix and vector of even indices')
   end
   sizex = size(x); transposex = false;
   if sizex(1) ~= n, x = x'; transposex = true; sizex = size(x); end
   if sizex(1) ~= n, error('dimension mismatch UP and x'); end
   m = sizex(2);
else
   [n m] = size(x); transposex = false;
   if nargin < 3, e = (1:2:n); end
   ne = length(e);
   no = n-ne;
   P = zeros(no,ne);  
end
if D1 == true, D = eye(ne); end
o = (1:n); o(e) = 0; o = find(o);
if length(o) ~= no,
   error('dimension mismatch prediction matrix and vector of odd indices')
end


y = x;

thisstepisprediction = nUP-2*floor(nUP/2);
for s = 1:nUP-1,
   if thisstepisprediction == 1,
      P = UP{s};
      y(o,1:m) = y(o,1:m) - P*y(e,1:m);
      thisstepisprediction = 0;
   else
      U = UP{s};
      y(e,1:m) = y(e,1:m) + U*y(o,1:m);
      thisstepisprediction = 1;
   end
end
if nUP>0, P = UP{nUP}; end
y(e,1:m) = D\y(e,1:m);
y(o,1:m) = y(o,1:m) - P*y(e,1:m);
if nargout==2, yo = y(o,1:m); y = y(e,1:m); end

if transposex == true, y = y'; end
