 
% Illustrates the singular values of orthogonal and non-orthogonal projections
% onto a coarse scale B-spline basis
% NOTE: the numeric results may have changed a bit compared to the plots in the
% 2016 paper (Jansen, Non-equispaced B-spline wavelets) since the update of the
% in ThreshLab version 4.3.2 (March 2017).
% The conclusions of the experiment remain unchanged

forestgreen = [34 139 34]/255;
purple = [128 0 128]/255;
if exist('gridnumber') ~= 1, gridnumber = 1; end
if exist('randomgrid') ~= 1, randomgrid = false; end
if exist('reallyrandomsamples') ~= 1, reallyrandomsamples = false; end
if exist('dualvanishingmoments') ~= 1, dualvanishingmoments = 4; end
if exist('nlevels') ~= 1, nlevels = 5; end
if exist('primalvanishingmoments') ~= 1, primalvanishingmoments = 1; end
if exist('nonzerodiags') ~= 1, nonzerodiags = primalvanishingmoments+2; end
if exist('samplesize') ~= 1, samplesize = 1000; end
if exist('usecolors') ~= 1, usecolors = true; end
if exist('fontsize') ~= 1, fontsize = 14; end
if exist('WTmethod') ~= 1, WTmethod = 'Bspline'; end
bf = {'fontsize',fontsize,'fontweight','b'};
bfit = {bf{:},'fontangle','italic'};

nu = max(nonzerodiags,primalvanishingmoments);
clear nonzerodiags;

if reallyrandomsamples == false, 
   initstate = 0;
else
   initstate = randn('state');
end
if usecolors == true,
   cc = {'k','m','b','r','g'};
else
   cc = {'k','k','k','k','k'};
end
mm = {'o','d','^','v','s'};

N = samplesize;
I = sparse(eye(N));
dualmom = dualvanishingmoments;
primmom = primalvanishingmoments;
x = makegrid(N,gridnumber,randomgrid)';
M = nlevels;

randn('state',initstate); 
err = randn(N,1);

F = Bsplinebasis(x,x,dualmom);
Sigmay = I;

[Wtmom, nL] = FWT2G1D(x,I,dualmom,nu,M,WTmethod);
Wmom = IWT2G1D(x,I,dualmom,nu,M,WTmethod);
VL = Wmom(1:N,1:nL);
VtLmom = Wtmom(1:nL,1:N);
PLmom = VL*VtLmom;
Sigmawmom = Wtmom*Sigmay*Wtmom';
stdevwmom = sqrt(diag(Sigmawmom));

[VtLSmom, nL] = FWT2G1D(x,I,dualmom,[primmom nu-primmom],M,WTmethod);
VLSmom = IWT2G1D(x,I,dualmom,[primmom nu-primmom],M,WTmethod);
VL = VLSmom(1:N,1:nL);
VtLLSmom = VtLSmom(1:nL,1:N);
PLLSmom = VL*VtLLSmom;
SigmawLSmom = VtLSmom*Sigmay*VtLSmom';
stdevwLSmom = sqrt(diag(SigmawLSmom));


VtLS = FWT2G1D(x,I,dualmom,[0 Inf],M,WTmethod);
VtLLS = VtLS(1:nL,1:N);
PLLS = VL*VtLLS;

VtLSapprx1 = FWT2G1D(x,I,dualmom,[0 nu-primmom],M,WTmethod);
VLSapprx1 = IWT2G1D(x,I,dualmom,[0 nu-primmom],M,WTmethod);
VtLLSapprx1 = VtLSapprx1(1:nL,1:N);
VLLSapprx1 = VLSapprx1(1:N,1:nL);
PLLSapprx1 = VL*VtLLSapprx1;
SigmawLSapprx1 = VtLSapprx1*Sigmay*VtLSapprx1';
stdevwLSapprx1 = sqrt(diag(SigmawLSapprx1));

VtLSapprx2 = FWT2G1D(x,I,dualmom,[0 nu],M,WTmethod);
VLSapprx2 = IWT2G1D(x,I,dualmom,[0 nu],M,WTmethod);
VtLLSapprx2 = VtLSapprx2(1:nL,1:N);
VLLSapprx2 = VLSapprx2(1:N,1:nL);
PLLSapprx2 = VL*VtLLSapprx2;
SigmawLSapprx2 = VtLSapprx2*Sigmay*VtLSapprx2';
stdevwLSapprx2 = sqrt(diag(SigmawLSapprx2));


etamom = FWT2G1D(x,err,dualmom,nu,M,WTmethod);
etamom(nL+1:N) = 0;
errmom = IWT2G1D(x,etamom,dualmom,nu,M,WTmethod);

etaLSmom = FWT2G1D(x,err,dualmom,[primmom nu-primmom],M,WTmethod);
etaLSmom(nL+1:N) = 0;
errLSmom = IWT2G1D(x,etaLSmom,dualmom,[primmom nu-primmom],M,WTmethod);

etaLS = FWT2G1D(x,err,dualmom,[0 Inf],M,WTmethod);
etaLS(nL+1:N) = 0;
errLS = IWT2G1D(x,etaLS,dualmom,[0 Inf],M,WTmethod);

etaLSapprx1 = FWT2G1D(x,err,dualmom,[0 nu-primmom],M,WTmethod);
etaLSapprx1(nL+1:N) = 0;
errLSapprx1 = IWT2G1D(x,etaLSapprx1,dualmom,[0 nu-primmom],M,WTmethod);

etaLSapprx2 = FWT2G1D(x,err,dualmom,[0 nu],M,WTmethod);
etaLSapprx2(nL+1:N) = 0;
errLSapprx2 = IWT2G1D(x,etaLSapprx2,dualmom,[0 nu],M,WTmethod);

figure(1)
plot(x,err,'color',[1 1 1]*0.7)
hold on
plot(x,errLSmom,'m','linewidth',2)
plot(x,errLS,'k','linewidth',2)
plot(x,errLSapprx1,'b','linewidth',2)
plot(x,errLSapprx2,'r','linewidth',2)
plot(x,errmom,'g','linewidth',2)
hold off
axis([0 1 -3 3])

figure(2)
figpos = get(gcf,'position');
figpaperpos = get(gcf,'paperposition');
widthfactor = 2;
figpos(3) = figpos(4)*widthfactor;
figpaperpos(3) = figpaperpos(4)*widthfactor;
set(gcf,'position',figpos)
set(gcf,'paperposition',figpaperpos)

plotspecs = {'linewidth',2,'markerfacecolor','w','markersize',7};
sigmaLS = svd(PLLS);
sigmamom = svd(PLmom);
sigmaLSmom = svd(PLLSmom);
sigmaLSapprx1 = svd(PLLSapprx1);
sigmaLSapprx2 = svd(PLLSapprx2);
nL150 = ceil(3*nL/2);
p1 = plot(sigmaLS(1:nL150),[cc{1} '-' mm{1}],plotspecs{:});
hold on
p2 = plot(sigmaLSmom(1:nL150),[cc{2} '-' mm{2}],plotspecs{:});
p3 = plot(sigmaLSapprx1(1:nL150),[cc{3} '-' mm{3}],plotspecs{:});
p4 = plot(sigmaLSapprx2(1:nL150),[cc{4} '-' mm{4}],plotspecs{:});
aa = axis;
p5 = plot(sigmamom(1:nL150),[cc{5} '-' mm{5}],plotspecs{:});
hold off
% make reasonable choice for range on axes
aa(4) = min(aa(4),max(10,sigmamom(1)));
% aa(2) = 2*nL-1;
aa(2) = nL150 +5;
aa(4) = aa(4)+1;
aa(3) = aa(3)-(aa(4)-aa(3))/15;
axis(aa)
title('SVD projections W*Wtilde',bf{:})
axis off
drawaxes('ytick',(0:aa(4)),'xtick',nL,'xticklabel','')
ppp = [p1 p2 p3 p4 p5];
legend(ppp,'Orthogonal','p moments, \nu-p apprx. orth.',...
       'no moments, \nu-p apprx. orth','\nu apprx. orth.','\nu moments')
set(findobj('Type','text'),bf{:})
text(nL-0.5,aa(3),'n_L',bfit{:})


% Norms of singular value vectors (Frobenius norm)
normsvLS = norm(sigmaLS)/sqrt(nL)
normsvLSmom = norm(sigmaLSmom)/sqrt(nL)
normsvLSapprx1 = norm(sigmaLSapprx1)/sqrt(nL)
normsvLSapprx2 = norm(sigmaLSapprx2)/sqrt(nL)
normsvmom = norm(sigmamom)/sqrt(nL)
