
function y = leastsquarespolynomial(x,x0,y0,p);

% leastsquarespolynomial - ThreshLab2/Irregular/1D/ --- least squares
% polynomial
%   Usage
%      y = leastsquarespolynomial(x,x0,y0,p);
%   Inputs
%      x  points in which interpolating polynomial is evaluated
%      x0 x-coordinates of interpolation points
%      y0 y-coordinates of interpolation points
%      p  degree of the polynomial (default 0)
%   Outputs
%      y  
%   Description
%      y0 may be a matrix (check sizes for consistency with x0)
%      x may be a vector
%      If x is a scalar, then y is a column vector if x0 is a row vector and
%      vice versa
%      If x is a row vector, then the number of columns in y equals the number
%      of columns in x
%      If x is a column vector, then the number of rows in y equals the number
%      of rows in x
%      The other dimension in y is determined by the dimension of y0 not
%      corresponding to x0
%   See also
%      help interpolynomialprediction

if nargin < 4, p = 0; end
[m n] = size(x0);
if nargin < 3, y0 = eye(max(m,n)); end
x0transpose = 0;
if m > n, x0 = x0'; y0 = y0'; [m n] = size(x0); x0transpose = 1; end
if m > 1, error('input argument x0 must be a scalar or a 1D-vector'), end

[r s] = size(y0);
if ~(n == s),
   if ~(n == r),
      error('dimension mismatch: inputs x0 and y0')
   else
      y0 = y0'; [r s] = size(y0);
   end
end
% x0 is reshaped as a row vector; y0 is reshaped accordingly, such that all
% *rows* of y0 match the dimension of x0.
% x is also reshaped as a row vector

[M N] = size(x);
finaltranspose = 0;
if M > N, finaltranspose = 1; x = x'; [M N] = size(x); end
if M > 1, error('input argument x must be a scalar or a 1D-vector'), end
if N == 1, finaltranspose = x0transpose; end

if p == 0,
   X = ones(n,1);
   Xo = ones(N,1);
else
   x00 = x0'-mean(x0);
   xoo = x'-mean(x0);
   X = [ones(n,1) x00];
   Xo = [ones(N,1) xoo];
   for q=2:p, X = [X x00.^q]; Xo = [Xo xoo.^q]; end
end
Y = y0';

y = Xo*((X'*X)\(X'*Y));

if finaltranspose==false, y = y'; end
