function [match1 match2] = matchpoints(points1,points2,x,y,z);

% matchpoints  ThreshLab2/Irregular/1D/ --- finds closest matches between 2
%                                           sets of points
%   Usage
%     [match1 match2] = matchpoints(points1,points2,x,y,z);
%   Inputs
%     points1  integer vector, index into (x,y,z)
%     points2  integer vector, index into (x,y,z)
%     x        x-coordinates of scattered data (default (1:n))
%     y        y-coordinates of scattered data (default zeros(1,n))
%     z        z-coordinates of scattered data (default zeros(1,n))
%   Outputs
%     match1   integer vector of length(points1), indices into points2
%     match2   integer vector of length(points2), indices into points1
%   Description
%   See also

points1 = row(points1); points2 = row(points2);
if nargin<3,
   n = max([points1 points2]); x = (1:n);
else
   n = length(x); x = row(x);
end
if nargin<4, y = zeros(size(x)); else, y = row(y); end
if nargin<5, z = zeros(size(x)); else, z = row(z); end
n1 = length(points1); n2 = length(points2);
match1 = zeros(size(points1));
match2 = NaN(size(points2));
for p = 1:n1,
   d = (x(points1(p))-x(points2)).^2 + (y(points1(p))-y(points2)).^2 + ...
       (z(points1(p))-z(points2)).^2;
   [d1 match1(p)] = min(d);
end
for p = 1:n2,
   d = (x(points1)-x(points2(p))).^2 + (y(points1)-y(points2(p))).^2 + ...
       (z(points1)-z(points2(p))).^2;
   [d2 match2(p)] = min(d);
   if match1(match2(p)) ~= p,
      % we haven't found a couple. points2(p) cannot claim match2(p)
      match2(p) = NaN;
   end
end
for p = 1:n1,
   if match2(match1(p)) ~= p, 
      % we haven't found a match for points1(p)
      match1(p) = NaN;
   end 
end
if nargin<4,
   leftover1 = find(isnan(match1));
   leftover2 = find(isnan(match2));
   pp1 = points1(leftover1); pp2 = points2(leftover2);
   nl1 = length(leftover1);
   for l = 2:nl1-1,
      o = leftover1(l); p1 = points1(o);
      ll = find(x(pp2)>x(points1(o-1)) & x(pp2)<x(points1(o+1)));
      % this assumes that x(points1) is ordered
      if ~isempty(ll);
         [d i] = min((x(p1)-x(pp2(ll))).^2);
         match1(o) = leftover2(ll(i));
         match2(leftover2(ll(i))) = o;
      end
   end
end
