function [xj Nej] = multilevelgridfromodds(odds,N);

% multilevelgridfromodds - find all intermediate grids from odds at each scale
%  Usage
%    [xj Nej] = multilevelgridfromodds(odds,N);
%    [xj Nej] = multilevelgridfromodds(odds,x);
%  Inputs
%    odds     array or cell array of indices
%    N        size of finest scale grid
%    x        finest scale grid
%  Outputs
%    xj       cell array of grids (if input is x) 
%                        or indices into grids (if input is N)
%    Nej      array; contains lengths of all entries in xj
%  Description
%  See also
%    help IRT_2GHPU

if length(N)>1,
   x = N; N = length(x);
else
   x = (1:N);
end
M = length(odds);
evensj = (1:N);
if isnumeric(odds), % one-coefficient-at-a-time refinement
   for j = 1:M,
      oddj = odds(j);
      o = find(evensj==oddj);
      evensj(o) = 0;
      evensj = evensj(find(evensj));
      xj{j} = x(evensj);
      Nje(j) = length(evensj);
   end
elseif iscell(odds),
   for j = 1:M,
      oddsj = odds{j};
      o = find(ismember(evensj,oddsj));
      evensj(o) = 0;
      evensj = evensj(find(evensj));
      xj{j} = x(evensj);
      Nje(j) = length(evensj);
   end
end
