
function [even, odd] = splitfrombandwidth(x,h,nn);

%  ThreshLab/ThreshLab2/Irregular/1D/splitfrombandwidth -- partitions data 
%           into "evens" and "odds",
%           so that each "odd" has at least nn "even" neighbours within
%           distance h
%   Usage
%     [even, odd] = splitfrombandwidth(x,h,nn);
%   Inputs
%     x      data vector, grid location vector, ...
%     h      real scalar
%     nn     integer, minimum number of neighbours used for prediction
%   Outputs
%     even   ordered indices of even subset
%     odd    ordered indices of odd subset
%   Description
%   Note
%     other input arguments are ignored
%   See also
%     help splitevenodd

N = length(x);
if N == 1, N = x; x = makegrid(N,0); end

if nargin<3, nn = 2; end
if nargin<2, h = x(N)-x(1); end

[e o] = splitevenodd(N);
A = zeros(size(x));
for i=1:length(e),
   ei = e(i); A(ei) = (sum(abs(x(o)-x(ei))<h) > nn-1);
end
for i=1:length(o),
   oi = o(i); A(oi) = (sum(abs(x(e)-x(oi))<h) > nn-1);
end

even = 1; odd = []; k = 2;
while k < N+1,
   if A(k) == true, odd = [odd k]; k = k+1; end
   even = [even k]; k = k+1;
end
Ne = length(even);
if even(Ne)>N, even = even(1:Ne-1); end
