function Omega = combinebasesdiff(Omega1,Omega2,k1,k2)

% Combine two sets of smooth functions, by replacing Omega1(k1) with Omega2(k2)
% The reason for replacing and not just joining two sets is that two smaller
% sets have been created without knowing they were going to be joint. As a
% result, these constructions have not enough information of the higher order
% derivatives.

if nargin<3, k1 = NaN; end
if nargin<4, k2 = NaN; end
nutilde = NaN;
if isnumeric(Omega2), if max(size(Omega2))==1,
   x = column(Omega1); nutilde = Omega2;
   nx = length(x);
   Omega1 = powerdiff(x,nutilde);
   Omega2 = sincosdiff(x,nutilde);
   if isnan(k1), k1 = nutilde; k2 = 2; end
end, end
if isnan(nutilde),
   Omega0 = Omega1{1};
   nutilde = size(Omega0,2);
   nx = size(Omega0,1);
end
if isnan(k1), k1 = nutilde; end
if isnan(k2), k2 = k1; end
nk = min(length(k1),length(k2)); k1 = k1(1:nk); k2 = k2(1:nk);
nom = min(length(Omega1),length(Omega2));
Omega = cell(1,nom);
for q=0:nom-1,
   Omegaq = Omega1{q+1}; Omega2q = Omega2{q+1};
   Omegaq(1:nx,k1) = Omega2q(1:nx,k2);
   Omega{q+1} = Omegaq;
end

