
function M = hermitesplinemoments(knots,Dfknots,qq);

% hermitesplinemoments - ThreshLab2/Irregular/BrokenbasisWT/ 
%                 Hermite polynomial moments
% Usage
%   M = hermitesplinemoments(knots,Dfknots,qq);
% Input
%   knots   pair of knots/end points/boundary points
%   Dfknots (p+1)x2 matrix containing function values and derivatives (up to
%           the p-th derivative) in the knots
%   qq      integer vector
% Output
%   M       vector of length(qq), containing integral between knots(1) and
%           knots(2) of the function phi(x), defined by
%           hermitesplinesegment(knots,Dfknots)
% See also
%   help hermitesplinesegment


if nargin<3, qq = 0; end
nq = length(qq); mq = max(qq);
x0 = knots(1); x1 = knots(2); Deltax = x1-x0;
A = eye(mq+1);
for q = 1:mq,
   A(q+1,1:q+1) = round(factorial(q)./(factorial(0:q).*factorial(q:-1:0)))...
                .* (-x0).^(q:-1:0);
end
a = hermitesplinesegment(knots,Dfknots);
p = length(a)/2-1;
M = zeros(mq+1,2*p+2);
for q=0:mq,
   M(q+1,1:p+1) = Deltax.^(q+1:q+p+1)./(q+1:q+p+1);
   M(q+1,p+2:2*p+2) = Deltax.^(q+p+2:q+2*p+2)*...
	   factorial(q+p+1).*factorial(0:p)./factorial(q+p+2:q+2*p+2);
   M(q+1,p+2:2*p+2) = M(q+1,p+2:2*p+2).*(-1).^(0:p);
end
M = M*a;
M = A\M;
