
function [phi a X] = hermitesplinesegment(x,knots,Dfknots)

% hermitesplinesegment - ThreshLab2/Irregular/BrokenbasisWT/ Hermite polynomial
%                        interpolation between two points (knots)
% Usage
%   [phi a] = hermitesplinesegment(x,knots,Dfknots);
%   phi = hermitesplinesegment(x,knots,Dfknots);
%   a = hermitesplinesegment(knots,Dfknots);
% Input
%   x       vector of abscis values in which function is evaluated
%   knots   pair of knots/end points/boundary points
%   Dfknots (p+1)x2 matrix containing function values and derivatives (up to
%           the p-th derivative) in the knots
% Output
%   phi     vector of length(x), containing phi(x), so that
%           phi^(q)(x_i) = Dfknots(q+1,i)
%   a       vector of length 2*(p+1)
%           power coefficients: phi(x) = a(1)+a(2)*(x-x1)+a(3)*(x-x1)^2+... 
%                                      +a(p+1)*(x-x1)^p*(x2-x)
%                                      +a(p+2)*(x-x1)^p*(x2-x)^2+...
%           where x1 = knots(1), x2 = knots(2)
% See also
%   help hermitesplinemoments
%   help hermitespline

nox = false; if nargin<3, Dfknots = knots; knots = x; nox = true; end
m = length(x); x = column(x);
if size(Dfknots,2) ~= 2, Dfknots=Dfknots'; end
p = size(Dfknots,1)-1;
x1 = knots(1); x2 = knots(2); Deltax = x2-x1;
if p==1 & size(Dfknots,2)~=2, Dfknots=Dfknots'; p = size(Dfknots,1)-1; end
divdif = zeros(2*p+2,2*p+2);
divdif(1:p+1,1) = Dfknots(1,1);
divdif(p+2:2*p+2,1) = Dfknots(1,2);
for q=1:p,
   k = (1:p+1-q); divdif(k,q+1) = Dfknots(q+1,1)/factorial(q);
   k = (p+2-q:p+1); divdif(k,q+1) = (divdif(k+1,q)-divdif(k,q))/Deltax;
   k = (p+2:2*p+2-q); divdif(k,q+1) = Dfknots(q+1,2)/factorial(q);
end
for q=p+1:2*p+1, k = 1:2*p+2-q;
   divdif(k,q+1) = (divdif(k+1,q)-divdif(k,q))/Deltax;
end
a = divdif(1,1:2*p+2)';
if nox==true, % no input x, output of interest is just a
   phi = a;
else
   X = ones(m,2*p+2);
   for q=1:p, X(1:m,q+1) = (x-x1).^q; end
   for q=0:p, X(1:m,p+2+q) = (x-x1).^(p+1).*(x-x2).^q; end
   phi = X*a;
end
