
function Mom = smoothsetmoments(x,Omega,qq);

% smoothsetmoments - ThreshLab2/Irregular/BrokenbasisWT/ --- finds integrals
%          of Omega_k(x)*x^qq(q) between each pair of adjacent knots in x
% Usage
%   Mom = smoothsetmoments(x,Omega,nutilde,qq);
% Inputs
%   x       vector of size n (the knots)
%   Omega   matrix of size n*nutilde x nutilde
%           containing knot values and derivatives of set of smooth functions
%           (Other specifications of the smooth functions are also accepted,
%           they are transformed into the matrix representation above; see
%           help brokenbasis)
%   qq      integer vector, defining the moments to be computed
% Outputs
%   Mom   cell array of length(qq), containing the moments as n x nutilde
%         matrices, the first columns being zero 
% Note
%   This routine adopts Hermite interpolation on each segment (defined by each
%   pair of adjacent knots), i.e., interpolating function values and
%   derivatives, thus forming an Hermite spline interpolation on the whole
%   interval.
% See also
%   help brokenbasismoments
%   help hermitesplinemoments

if nargin<3, qq = 0; end
nu = length(qq); n = length(x);

[OmegaL Omega] = smoothsetmatrix(x,Omega);
nutilde = size(Omega,2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Mom = cell(1,nu);
for q=1:nu, Mom{q} = zeros(n,nutilde); end
for s = 1:n-1,
   segment = (s:s+1);
   rr = (s-1)*nutilde+(1:nutilde);
   knots = x(segment);
   for o=1:nutilde, % loop over the nutilde functions in Omega
      Dfknots = [OmegaL(rr,o) Omega(rr,o)];
      M = hermitesplinemoments(knots,Dfknots,qq);
      for q=1:nu,
         Momq = Mom{q}; Momq(s+1,o) = M(q); Mom{q} = Momq;
      end
   end
end
