
function M = Bsplinemoments(x,ptilde,q,ext);

% Bsplinemoments - ThreshLab2/Irregular/1D/ --- find moments in Bspline basis
% Usage
%    M = Bsplinemoments(x,ptilde,q,ext);
% Inputs
%    x       knots of the spline basis, vector of length n
%    ptilde  number of vanishing moments (ptilde-1 is degree of polynomials)
%    q       vector of exponents (must not contain -1, default is 0)
%            vector of length nq
%    ext     (optional) binary value (default true) 
%            The setting ext=false computes the moments of the interior basis 
%            functions only.
%            ext=true means that the basis will be extended so that the basis
%            functions sum to one. (i.e., the basis satisfies the
%                                         partition of unity)
% Outputs
%     M    matrix of size (n+ptilde-2) x nq (if ext==true)
%                         n x nq            (if ext==false)
% Description
%     Applies recursion on order ptilde for B splines
%     This routine was introduced in ThreshLab version 4.3.2
% Note
%     It is assumed that the boundaries contain coinciding knots
% See Also
%     help Bsplinebasis
%     help initmom (for moments of characteristic/indicator functions)
%          

if nargin<4, ext = true; end
if nargin<3, q = 0; end
x = column(x);
n = length(x);
nq = length(q);
nPhi = n-1; 
% at the end, we will have for ext==true that nPhi = n+ptilde-2;
nPhi1 = n;
% nPhi1 is for exception handling for s=2. After the calculation for s=2, nPhi1
% will take the value of nPhi


M = zeros(nPhi,nq);
for c = 1:nq,
   pq = q(c)+ptilde;
   M(1:n-1,c) = (x(2:n).^pq - x(1:n-1).^pq)./pq;
end
qq = q+ptilde-1;
b = 0;

for s = 2:ptilde,
   M0 = M;
   t = floor(s/2); r = s-2*t; sqq = (s-1)./qq;
   for k = 2-r:t,
      M(k,1:nq) = -sqq.*(M0(k+r-1,1:nq)/(x(k-t+s-1)-x(1)) - ...
                         M0(k+r,1:nq)/(x(k-t+s)-x(1)));
   end
   for k = t+1:nPhi-s+t,
      M(k,1:nq) = -sqq.*(M0(k+r-1,1:nq)/(x(k-t+s-1)-x(k-t)) - ...
                         M0(k+r,1:nq)/(x(k-t+s)-x(k-t+1)));
   end
   for k = nPhi-s+t+1:nPhi-r,
      M(k,1:nq) = -sqq.*(M0(k+r-1,1:nq)/(x(nPhi)-x(k-t)) - ...
                         M0(k+r,1:nq)/(x(nPhi1)-x(k-t+1)));
   end
   if r==1,
      M(nPhi,1:nq) = x(nPhi).^qq./qq-sqq.*M0(nPhi,1:nq)/(x(nPhi)-x(nPhi-t));

      % (k = 0)
      A = sqq.*M0(1,1:nq)/(x(-t+s)-x(1))-x(1).^qq./qq;
      x = [x(1); x]; M = [A; M]; nPhi = nPhi+1; b = b+1;
   end
   if r==0,
      M(1,1:nq) = sqq.*M0(1,1:nq)/(x(1-t+s)-x(1))-x(1).^qq./qq;

      k = nPhi+1;
      Z = x(k).^qq./qq-sqq.*M0(nPhi,1:nq)/(x(k)-x(k-t));
      x = [x; x(k)]; M = [M; Z]; nPhi = nPhi+1;
   end
   qq=qq-1; nPhi1 = nPhi;
end
if ptilde == 0, % B-splines of order 0 (degree -1) are taken to be Dirac
                % impulses
   for c = 1:nq, M(1:n,c) = x.^q(c); end
end

if ext==false,
   if ptilde==1,
      M = [M;zeros(size(q))];
   elseif ptilde>1,
      M = M(b+(1:n),1:nq);
   end
end
