
function [DPhi D] = derivBsplinebasis(x,knots,ptilde,ext);

% derivBsplinebasis - ThreshLab2/Irregular/1D/ --- derivatives of Bsplines
% Usage
%    DPhi = derivBsplinebasis(x,knots,ptilde);
%    [DPhi D] = derivBsplinebasis(x,knots,ptilde);
% Inputs
%    x       points in which splines are evaluated, vector of length n
%    knots   knots of the spline basis, vector of length nk
%    ptilde  number of vanishing moments (ptilde-1 is degree of polynomials)
%    ext     (optional) binary value (default true) 
%            By setting ext=false one generates the interior basis functions
%            only. The number of basis functions then equals the number of
%            knots (= nk)
%            ext=true means that the basis will be extended so that the basis
%            functions sum up to one. The number of basis functions then equals
%            nk+ptilde-2
% Outputs
%    DPhi    matrix of size n x (nk+ptilde-2) 
%    D       (optional) (nk+ptilde-3) x (nk+ptilde-2) matrix so that
%               DPhi = (ptilde-1)*Phi*D 
%               with Phi the B-spline basis of order ptilde-1
% Description
% Note
%    The routine assumes that the first and last knots have a multiplicity to
%    deal with all definitions involving knots with numbers outside {1,...,n}
% See Also
%     help Bsplinebasis

x = column(x);
n = length(x);
nk = length(knots);
Phi = Bsplinebasis(x,knots,ptilde-1,true);
q = floor(ptilde/2); r = ptilde-2*q;
knots = [ones(ptilde-2,1)*knots(1);column(knots);ones(ptilde-2,1)*knots(nk)];
nPhi = nk+ptilde-3;
Delta = knots(ptilde:ptilde+nPhi-1)-knots(1:nPhi);
D = [zeros(nPhi,1) diag(1./Delta)]-[diag(1./Delta) zeros(nPhi,1)];
DPhi = (ptilde-1)*Phi*D;
if nargin<4, ext=true; end
if ext==false, DPhi = DPhi(1:n,q+1:q+nk); end
