function [y, Ne] = IMLPT1D(x,w,M,varargin);

% IMLPT1D -- ThreshLab2/Irregular/MultiscaleKernel -- ThreshLab's routine for
%            the Inverse Multiscale Local Polynomial Transforms, 1D, which is
%            a Burt-Adelson's pyramid on irregular point sets with
%                prefilter F, prediction P, update U
%  Usage
%    y = IMLPT1D(x,w,M,varargin);
%  Inputs
%    x      grid-locations of observations (time, space)
%    w      wavelet/pyramid coefficients
%    M      number of resulution levels
%    varargin several options (see below)
%  Outputs
%    y      vector of size(x) with reconstructed observations/signal
%    Ne     (optional) number of scaling coefficients (dependent on M)
%  Description
%    Thanks to the overcompleteness of the decomposition, this reconstruction
%    does not depend on the prefilter step in the forward transform.
%    The reconstruction uses (= undoes) one update step and prediction step.
%    These steps may be preceded by a prefilter step (which may be identical to
%    the prefilter in the decomposition)
%    If w is a matrix, then the transform is performed on its COLUMNS
%  Examples
%  See also
%    help FMLPT1D

transposey = false;
if size(w,1) == 1,
   transposey = true;
   w = w';
end

N = length(x);
o = sparse(zeros(N,1));
infofromFMLPT = FMLPT1D(x,o,M,varargin{:},'addoutputinfo');
predictions = infofromFMLPT{1};
finalupdates = infofromFMLPT{2};
hulls = infofromFMLPT{3};
Ne = infofromFMLPT{4};
odds = infofromFMLPT{5};
% odds = findoddsinfinestgrid(odds,N,true);

c = size(w,2);
y = w;
Nj = Ne;
Njj = Ne;
for j = 1:M,
   Ne = Nj;
   yeven = y(1:Ne,1:c);
   o = odds{j};
   No = length(o);
   Nj = Ne+No;
   e = setdiff(1:Nj,o);
   yodd = zeros(Nj,c);
   Q = hulls{j}; Qnon0 = find(Q>eps); Nj1 = length(Qnon0);
   yodd(Qnon0,1:c) = w(Njj+1:Njj+Nj1,1:c);
   % UPDATE
   U = finalupdates{j};
   yeven = yeven - U*yodd;
   % PREDICTION %
   P = predictions{j};
   yodd = yodd + P*yeven;
   % MERGE %
   yyeven = zeros(size(yodd)); yyeven(e,1:c) = yeven;
   y(1:Nj,1:c) = (1-Q).*yyeven+Q.*yodd;
   Njj = Njj+Nj1;
end
y = y(1:Nj,1:c);

if transposey == true, y = y'; end

