
function wlevels = MLPTlevels(Ne,odds,hulls,w);

% MLPTlevels -- identifies resolution levels in MLPT output vector
%  Usage
%     wlevels = MLPTlevels(Ne,odds,hulls,w);
%     wlevels = MLPTlevels(Ne,odds,hulls);
%  Inputs
%    Ne     number of coarse scaling coefficients (output of FMLPT1D)
%    odds   cell of refinement points at each level (output of FMLPT1D)
%    hulls  cell of filters used in reconstruction (output of FMLPT1D)
%    w      MLPT coefficient vector (optional)
%  Outputs
%    wlevels cell of coefficients arranged by level (if input w is given)
%            OR cell of indices into w, arranged by level (if w is not given)
%  Description
%  See also
%    help constructMLPTtree
%    help IMLPT1D


J = length(odds)+1;
wlevels = cell(J,1);

wlevels{1} = (1:Ne);
Nj = Ne;
Njj = Ne;
for j = 1:J-1,
   Ne = Nj;
   o = odds{j};
   No = length(o);
   Nj = Ne+No;
   e = setdiff(1:Nj,o);
   Q = hulls{j}; Qnon0 = find(Q>eps); Nj1 = length(Qnon0);
   wlevels{j+1} = (Njj+1:Njj+Nj1);
   Njj = Njj+Nj1;
end

if nargin>3, for j = 1:J, wlevels{j} = w(wlevels{j}); end, end

% Copyright (c) Maarten Jansen
% 
% This software is part of ThreshLab and is copyrighted material. 
