
function H = findhullMLPT(x,x1,h,varargin)

% findhullMLPT -- ThreshLab2/Irregular/MultiscaleKernel --
%               element of multiscale local polynomial prediction
%  Usage
%    H = findhullMLPT(x,xo,h,type);
%  Inputs
%    x      covariate values in which the hull is evaluated
%    x1     values in which hull must be one
%    h      bandwidth: minimum distance between x1 and x0 where hull(x1)=1
%                      and hull(x0) = 0
%    type   cell, char, or numerical value indicating how hull(x) looks like
%           between hull(x0) and hull(x1) (see below)
%  Outputs
%    H      vector of values hull(x), where 0<=hull(x)<=1
%  Description
%    possible values of type:
%    'kernel',kerneltype 
%  Note
%  See also
%    help FMLPT1D
%    help FMLPT1D1step
%    help IMLPT1D
%    help IMLPT1D1step

type = {1};
if nargin==0, x = 0; end

nvarargin = length(varargin);
if nvarargin > 0, type = {}; end
for k = 1:nvarargin, vark = varargin{k};
   if iscell(vark), type = {type{:},vark{:}};
   else, type = {type{:},vark};
   end
end
nt = length(type);
type1 = type{1};
t = 1;
if ischar(type1),
   x = row(x); x1 = row(x1);
   n = length(x);
   n1 = length(x1);
   H = zeros(size(x)); d = Inf*ones(size(x));
   if n1 > 1, 
      d = min(abs(ones(n1,1)*x-x1'*ones(1,n))); % minimum over elements in x1
   elseif n1 == 1,
      d = abs(ones(n1,1)*x-x1'*ones(1,n));
   end
   H(d<h/2) = 1;

   type1 = [type1 '     '];
   switch type1(1:6),
   case {'kernel'},
      if nt==1, kerneltype = 'unif';
      else, kerneltype = type{2}; t = 2;
      end
      H = kernelestimation(x,x,H,h/2,kerneltype);
   case {'locpol','localp'},
      kerneltype = 'unif'; degree = 1;
      if nt>1, t = 2; type2 = type{2};
         if ischar(type2), kerneltype = type2; else, degree = type2; end
      end
      if nt>2, t = 3; type3 = type{3};
         if ischar(type3), kerneltype = type3; else, degree = type3; end
      end
      H = locpolestimation00(x,x1,H,h/2,kerneltype,degree);
   case {'cos   '},
      ii = find(d<h);
      H(ii) = (cos(d(ii)/h*pi)+1)/2;
   end
elseif isnumeric(type1),
   H = ones(size(x)); t = nt;
end
if t<nt,
   typent = type{nt};
   if ischar(typent), 
      typent = [typent '     ']; 
      if all(typent(1:4) == 'fill'),
         x1 = [x(1) x1 x(n)];
         for i = 1:n1+1,
            ii = find(x<x1(i+1)&x>x1(i));
            if all(H(ii))>0, H(ii) = 1; end
         end
      end
   end
end
