
function midpoint = findmidpointsinsparsematrix(A);

% findmidpointsinsparsematrix -- finds central elements in sparse matrix
%  Usage
%    midpoint = findmidpointsinsparsematrix(A);
%  Inputs
%    A      n x m matrix
%  Outputs
%    midpoint integer vector of length min(n,m) with entries in
%             {1,...,max(n,m)}
%  Description
%    finds a column in each row of A around which sparsity of A is defined.
%    the central column in each row of A is defined by a the maximum value over
%    all elements on a smoothed version of each row
%  Note
%    findmidpointsinsparsematrix is an automatic routine for finding the
%    parameters in sparse solvers of AX=B. It is, however, a bottleneck, so
%    avoiding it may speed up the solver significantly.
%  See also:
%    help sparsesolveAXisB
%    help findbiorthfilter

[n m] = size(A);
A00 = abs(A);  A00 = sparse(A00.*(abs(A00)>eps));
zerorows = [];
for i = 1:n,
   nz = find(A00(i,1:m)>eps);
   if ~isempty(nz),
      bw = nz(length(nz))-nz(1); bw2 = ceil(bw/2);
      O = sparse(eye(m));
      for d=1:bw2,
         O = O + sparse(diag(ones(1,m-d),d))+sparse(diag(ones(1,m-d),-d));
      end
      % O = O*sparse(diag(1./sum(O)));
      A00(i,1:m) = A00(i,1:m)+A00(i,1:m)*O;
   else
      zerorows = [zerorows i];
   end
end
[dummy midpoint] = max(A00,[],2);
midpoint(zerorows) = NaN;

% Copyright (c) Maarten Jansen
%
% This software is part of ThreshLab and is copyrighted material.
