% This is file
% ThreshLab/ThreshLab2/MultiscaleKernel/illustrateFMLPT1D.m
% part of ThreshLab
%
%
% This test routine illustrates the working of multiscale local
% polynomial/kernel smoothing with thresholding. For several parameters and
% strategies, the output from thresholding is computed
%
% Scroll down in the source file illustrateFMLPT1D.m to see more comments
% and discussions


if exist('gridnumber') ~= 1, gridnumber = 1; end
if exist('realrandom') ~= 1, realrandom = 0; end
if exist('samplesize') ~= 1, samplesize = 2067; end
N = samplesize;
x = makegrid(N,gridnumber,realrandom);

f = makesignal(x,'skyline');
y = makenoisy(f,1,0,10);
I = sparse(eye(N));
varerror = var2(y-f);
stdeverror = sqrt(varerror);
M = floor(log2(N));

% M = 5;

nt = 2;
n = 2;
typeofkernel = 'cos';
bandwidths = 6/N;


disp('**********************************************************')
% Linear interpolating prediction, no prefilter, no update

disp('Linear interpolating prediction, no prefilter, no update')

w = FMLPT1D(x,y,M,'P','intpol','nt',nt);
Psitilde = FMLPT1D(x,I,M,'P','intpol','nt',nt);

yy = IMLPT1D(x,w,M,'P','intpol','nt',nt);
Iw = eye(length(w));
Psi = IMLPT1D(x,Iw,M,'P','intpol','nt',nt);

maxerr =  max(abs(y-yy))
k = 26;
plot(x,Psi(1:N,k))

pause(2)
disp('**********************************************************')

% Cubic interpolating prediction, no prefilter, 2-taps update

disp('cubic interpolating prediction, 2taps update, no prefilter')
nt = 4;
n = 2;

% w = FMLPT1D(x,y,M,'P','intpol','nt',nt,'U','primalmom','n',2);
% explicit declaration of 'U','primalmom' is obsolete and optional (version
% 4.3.2)
w = FMLPT1D(x,y,M,'P','intpol','nt',nt,'n',2);
Psitilde = FMLPT1D(x,I,M,'P','intpol','nt',nt,'n',2);

yy = IMLPT1D(x,w,M,'P','intpol','nt',nt,'n',2);
Iw = eye(length(w));
Psi = IMLPT1D(x,Iw,M,'P','intpol','nt',nt,'n',2);

maxerr =  max(abs(y-yy))
k = 26;
plot(x,Psi(1:N,k))

pause(2)
disp('**********************************************************')

% Cubic interpolating prediction, Unb.Haar prefilter, 2-taps update

disp('cubic interpolating prediction, 2taps update, Unb.Haar prefilter')

w = FMLPT1D(x,y,M,'P','intpol','nt',nt,'n',2,'Ht','UnbHaar');
Psitilde = FMLPT1D(x,I,M,'P','intpol','nt',nt,'n',2,...
                     'Ht','UnbHaar');

yy = IMLPT1D(x,w,M,'P','intpol','nt',nt,'n',2);
Iw = eye(length(w));
Psi = IMLPT1D(x,Iw,M,'P','intpol','nt',nt,'n',2);

maxerr =  max(abs(y-yy))
k = 26;
plot(x,Psi(1:N,k))

pause(2)
disp('**********************************************************')

% Next is Haar prediction (nt = 1) + Unb.Haar-prefilter; no update

disp('Haar prediction (nt = 1), no update, Unb.Haar prefilter')

w = FMLPT1D(x,y,M,'P','intpol','nt',1,'Ht','UnbHaar');
Psitilde = FMLPT1D(x,I,M,'P','intpol','nt',1,'Ht','UnbHaar');

yy = IMLPT1D(x,w,M,'P','intpol','nt',1);
Iw = eye(length(w));
Psi = IMLPT1D(x,Iw,M,'P','intpol','nt',1);

maxerr =  max(abs(y-yy))
k = 26;
plot(x,Psi(1:N,k))

pause(2)
disp('**********************************************************')

% Kernel prediction, Unb.Haar-prefilter, no update

disp('Kernel prediction, Unb.Haar-prefilter, no update')

hJ = bandwidths;
w = FMLPT1D(x,y,M,'P','kernel','type',typeofkernel,'h',hJ,'Ht','UnbHaar');
Psitilde = ...
     FMLPT1D(x,I,M,'P','kernel','type',typeofkernel,'h',hJ,'Ht','UnbHaar');

yy = IMLPT1D(x,w,M,'P','kernel','type',typeofkernel,'h',hJ);
Iw = eye(length(w));
Psi = IMLPT1D(x,Iw,M,'P','kernel','type',typeofkernel,'h',hJ);
maxerr =  max(abs(y-yy))
k = 26;
plot(x,Psi(1:N,k))

pause(2)
disp('**********************************************************')

% Local polynomial prediction, nt = 2; Unb.Haar-prefilter, no update
% Remark: current version of ThreshLab (3.2.1) has no final solution for local
% polynomial prediction when local neighborhood contains too few evens for
% non-singular local polynomial prediction; this results in NaN in the output.

disp('Local polynomial prediction, nt = 2; Unb.Haar-prefilter, no update')

ker = typeofkernel;
hJ = bandwidths;
nt = 2;

w = FMLPT1D(x,y,M,'P','locpol','type',ker,'h',hJ,'nt',nt,'Ht','UnbHaar');
Psitilde = ...
     FMLPT1D(x,I,M,'P','locpol','type',ker,'h',hJ,'nt',nt,'Ht','UnbHaar');

yy = IMLPT1D(x,w,M,'P','locpol','type',ker,'h',hJ,'nt',nt);
Iw = eye(length(w));
Psi = IMLPT1D(x,Iw,M,'P','locpol','type',ker,'h',hJ,'nt',nt);
maxerr =  max(abs(y-yy))
k = 26;
plot(x,Psi(1:N,k))

pause(2)
disp('**********************************************************')

% Local polynomial prediction, nt = 2; shared invariance pre-filter, no update

disp('Local polynomial prediction, nt = 2; shared invariance prefilter, n=0')

w = FMLPT1D(x,y,M,'P','locpol','type',ker,'h',hJ,'nt',nt,'Ht','idem');
Psitilde = ...
     FMLPT1D(x,I,M,'P','locpol','type',ker,'h',hJ,'nt',nt,'Ht','idem');
wbis = FMLPT1D(x,y,M,'P','extlocpolestimation00',...
       'type',ker,'h',hJ,'nt',nt,'Ht','idem');


Iw = eye(length(w));

yy = IMLPT1D(x,w,M,'P','locpol','type',ker,'h',hJ,'nt',nt);
Psi = IMLPT1D(x,Iw,M,'P','locpol','type',ker,'h',hJ,'nt',nt);
maxerr =  max(abs(y-yy))

k = 26;
plot(x,Psi(1:N,k))

pause(2)
disp('**********************************************************')

% Local polynomial prediction, nt = 2; shared invariance pre-filter, two taps
%  update

disp('Local polynomial prediction, nt = 2; shared invariance prefilter, n=2')

w = FMLPT1D(x,y,M,'P','locpol','type',ker,'h',hJ,'nt',nt,'Ht','idem','n',2);
Psitilde = ...
     FMLPT1D(x,I,M,'P','locpol','type',ker,'h',hJ,'nt',nt,'Ht','idem','n',2);

Iw = eye(length(w));

yy = IMLPT1D(x,w,M,'P','locpol','type',ker,'h',hJ,'nt',nt,'n',2);
Psi = IMLPT1D(x,Iw,M,'P','locpol','type',ker,'h',hJ,'nt',nt,'n',2);
maxerr =  max(abs(y-yy))


k = 52;
plot(x,Psi(1:N,k))

pause(2)
disp('**********************************************************')

% Convex local polynomial prediction, nt = 2; shared invariance pre-filter, 
% two taps update
%
% A convex local polynomial prediction is obtained by a constraint least
% squared local polynomial fit, where the constraints are positive (and convex)
% prediction coefficients

[w, Ne, mom, odds] = FMLPT1D(x,y,M,'P','extlocpolestimation00','convex',1,...
           'kerneltype',ker,'bandwidth',hJ,'nt',2,'n',2,'Ht','idem');
Psitilde = FMLPT1D(x,I,M,'P','extlocpolestimation00','convex',1,...
           'kerneltype',ker,'bandwidth',hJ,'nt',2,'n',2,'Ht','idem');

Iw = eye(length(w));

yy = IMLPT1D(x,w,M,'P','extlocpolestimation00','convex',1,...
              'kerneltype',ker,'bandwidth',hJ,'nt',2,'n',n);
Psi = IMLPT1D(x,Iw,M,'P','extlocpolestimation00','convex',1,...
              'kerneltype',ker,'bandwidth',hJ,'nt',2,'n',n);
maxerr =  max(abs(y-yy))

j = 6; Nej = Ne; for i=1:j-1, Nej = Nej+length(odds{i}); end
k = Nej+1:Nej+length(odds{j});
plot(x,Psi(1:N,k),'k','linewidth',3)
hold on
k = 52;
plot(x,Psi(1:N,k),'r','linewidth',3)
hold off

pause(2)
disp('**********************************************************')

% Convex local polynomial prediction, nt = 2; shared invariance pre-filter,
% without global primal vanishing moments before update,
% two taps update
%
% The standard construction of the shared invariance pre-filter involves the
% preservation of the global primal vanishing moments. Imposing this global
% vanishing moment condition leads to a time consuming system of equations and
% may also be a source of instabilities.
%
% The update step takes care for (local) primal vanishing moments (local
% vanishing moments is the stronger version, while global vanishing moments are
% the weaker version of the concept)
%
% THE VERSION BELOW IS RECOMMENDED:
% it is numerically stable, faster than the alternatives, and maintains
% smoothness of the reconstruction

w = FMLPT1D(x,y,M,'P','extlocpolestimation00','convex',1,...
           'prefiltopt','nomoment',...
           'kerneltype',ker,'bandwidth',hJ,'nt',2,'n',2,'Ht','idem');
Psitilde = FMLPT1D(x,I,M,'P','extlocpolestimation00','convex',1,...
           'prefiltopt','nomoment',...
           'kerneltype',ker,'bandwidth',hJ,'nt',2,'n',2,'Ht','idem');

Iw = eye(length(w));

yy = IMLPT1D(x,w,M,'P','extlocpolestimation00','convex',1,...
              'kerneltype',ker,'bandwidth',hJ,'nt',2,'n',n);
maxerr =  max(abs(y-yy))



if exist('dobioprefilt') ~= 1, dobioprefilt = 0; end

if dobioprefilt == 1,
% Warning: subsequent decompositions use biorthogonal prefilter whose
% construction is SLOW and which is unstable
%
% Local polynomial prediction, nt = 1; biorthogonal pre-filter, no update
% next is very slow in current version (3.2.1)

w = FMLPT1D(x,y,M,'P','locpol','type',ker,'h',hJ,'nt',nt,'Ht','biortho');
Psitilde = ...
     FMLPT1D(x,I,M,'P','locpol','type',ker,'h',hJ,'nt',nt,'Ht','biortho');

Iw = eye(length(w));

y1 = IMLPT1D(x,w,M,'P','locpol','type',ker,'h',hJ,'nt',nt);
Psi1 = IMLPT1D(x,Iw,M,'P','locpol','type',ker,'h',hJ,'nt',nt);
maxerr1 =  max(abs(y-y1))

y2 = IMLPT1D(x,w,M,'P','locpol','type',ker,'h',hJ,'nt',nt,'H','biortho');
Psi2 = IMLPT1D(x,Iw,M,'P','locpol','type',ker,'h',hJ,'nt',nt,'H','biortho');
maxerr2 =  max(abs(y-y2))


k = 56;
plot(x,Psi1(1:N,k))
plot(x,Psi2(1:N,k),'r')

end
