
function y = integralkernel(x,h,kerneltype)

% integralkernel - ThreshLab2/Irregular/MultiscaleKernel/ --- evaluation of
%     kernel primitive for use in kernel smoothing or kernel density estimation
%   Usage
%      y = integralkernel(x,h,kerneltype)
%   Inputs
%      x      x-coordinates in which kernel primitive is evaluated
%      h      kernel bandwidth
%      kerneltype  string-type variable, alternatives are
%           'none','dirac','Dirac','kronecker','Kronecker'
%           'uniform','Uniform','unif'
%           'Triangle','triangle','tri'
%           'Epanechnikov'
%           'Quartic','quartic'
%           'Triweight','triweight'
%           'cosine','Cosine','cos'
%           'Gaussian','gaussian','gauss','Gauss'
%   Outputs
%      y    function values in x
%   See also
%      help kernelestimation


% x/h is supposed to be on [-1,1] or ]-Inf,Inf[
% kernels have integral equal to bandwidth h

if nargin < 2,
   h = 1;
end
if nargin < 3,
   if ischar(h),
      kerneltype = h; h = 1;
   else
      kerneltype = 'uniform';
   end
end

if length(h) == 1,
   h = h*ones(size(x));
end
if length(h) == length(x),
   if size(h)~=size(x), h = h'; end
   x = x./h;
end

switch kerneltype
case {'none','dirac','Dirac','kronecker','Kronecker'}
   y = (x>=0);
case {'uniform','Uniform','unif'}
   y = (x+1)/2;
case {'Triangle','triangle','tri'}
   y = (x+1).^2/2.*(x<0)+(2*x-x.^2+1)/2.*(x>=0);
case {'Epanechnikov'}
   y = (3*x-x.^3+2)/4;
case {'Quartic','quartic'}
   y = 0.5+15*(x-2*x.^3/3+x.^5/5)/16;
case {'Triweight','triweight'}
   y = 0.5+35*(x-x.^3+3/5*x.^5-x.^7/7)/32;
case {'cosine','Cosine','cos'},
   y = (1+sin(pi*x/2))/2;
case {'Gaussian','gaussian','gauss','Gauss'}
   y = cumgauss(x);
end
y(x<-1)=0;
y(x>1)=1;

