
function y = poscoefweightedLSpol(x,x0,y0,w0,p);

% weightedLSpol - ThreshLab2/Irregular/MultiscaleKernel/ --- 
%                  Weighted Least Squares Polynomial with positive coefficients
%   Usage
%      y = poscoefweightedLSpol(x,x0,y0,w0,p);
%   Inputs
%      x      x-coordinates in which polynomial is evaluated
%      x0     x-coordinates of locations where polynonial is constructed
%      y0     y-coordinates of locations where polynonial is constructed
%      w0     weights corresponding to y0 (default = 1)
%      p      degree of polynomial
%   Outputs
%      y      polynomial evaluated in x
%   Description
%      y(x) = sum_i c(i) y0(i), where either zero or positive
%   Notes
%   See also
%      help poscoefweightedLSpol

n = length(x);
n0 = length(x0);
if nargin < 4, w0 = ones(n0,1); end
if nargin < 5,
   if length(w0) == 1,
      p = w0;
      w0 = ones(n0,1);
   else
      p = 0;
   end
end


if size(y0,1) ~= n0, y0 = y0'; end
if size(y0,1) ~= n0, error('dimension mismatch x0 and y0'); end
if size(w0,1) ~= n0, w0 = w0'; end
if size(w0,1) ~= n0, error('dimension mismatch x0 and w0'); end

c = weightedLSpol(x,x0,eye(n0),w0,p);
mini = (1:n0);
eps = 1.e-10;
while any(c<-eps),
   [cmin i] = min(c);
   c(i) = 0;
   mini = setdiff(mini,i);
   x0mini = x0(mini);
   y0mini = y0(mini);
   w0mini = w0(mini);
   cmini = weightedLSpol(x,x0mini,eye(length(mini)),w0mini,p);
   c(mini) = cmini;
end
y = c*y0;
