
function [vertexangle CC] = anglesboundary(B,x,y);

% anglesboundary - ThreshLab2/Triangulations --- find inside angles
%   Usage
%      [vertexangle CC] = anglesboundary(B,x,y);
%   Inputs
%      B                ordered list of indices into x and y corresponding to
%                       vertices
%      x                vector of x-coordinates of vertices
%      y                vector of y-coordinates of vertices
%   Outputs
%      vertexangle      vector of size(B) with angles 
%      CC               boolean; 1 if B is ordered counterclockwise
%                                0 if B is ordered clockwise
%   Description
%      this function finds the inside angles of all corners on boundary B

n = length(B);
cyc = 0;
if B(n) == B(1),
   B = B(1:n-1);
   n = n-1;
   cyc = 1;
end
B1 = frwshift(B,1);
xx = x(B1) - x(B); yy = y(B1) - y(B);
cosphases = xx./sqrt(xx.^2+yy.^2);
sinphases = yy./sqrt(xx.^2+yy.^2);
phases = acos(cosphases);
negsines = (sinphases<0);
phases(negsines) = 2*pi-phases(negsines);
% the above 5 lines can be replaced by matlab's function
%  phases = angle(xx+sqrt(-1)*yy);
vertexangle = pi - (phases-frwshift(phases,-1));
vertexangle = vertexangle - floor(vertexangle/(2*pi))*2*pi;

% We now check whether vertexangles have been measured inside or outside the
% polygon. Inside angles sum up to (n-2)*pi, while outside angles sum up to 
% n*2*pi-(n-2)*pi = (n+2)*pi
eps = 1.e-4;
o = (abs(vertexangle)<eps | abs(vertexangle-2*pi)<eps);
noto = ~o;
o = find(o);
   % o are indices into angles close to 0 or 2*pi
   % vertices with angles near 0 or 2*pi will be eliminated from subsequent
   % steps, because the attributed angle value may be incorrect due to flipping
   % between 0 and 2*pi. The corrected value will be attributed afterwards
noto = find(noto);
n0 = length(o);
n1 = length(noto);

vertexangle1 = 2*pi-vertexangle;
sumangle = sum(vertexangle(noto));
sumangle1 = sum(vertexangle1(noto));
CC = 1;
if sumangle1<sumangle,
   vertexangle = vertexangle1; CC = 0;
end

for i=1:n0,
   oi = o(i);
   vertexangle(oi) = 2*pi*pointinside(x(B(oi)),y(B(oi)),B(noto),x,y);
end
