
function void = fillvoronoicells(x,y,f);

% fillvoronoicells - ThreshLab2/Triangulations --- make image of voronoi cells
%   Usage
%     fillvoronoicells(x,y,f);
%   Inputs
%     x     x-coordinates of 2d-scattered data
%     y     y-coordinates of 2d-scattered data
%     length(x) = length(y)
%     f     function values in each vertex
%   Outputs
%     figure with grey scale image
%   Description
%     f may have different length than x and y. This may prove interesting, for
%     instance by adding artificial vertices outside the data cloud of (x,y),
%     in order to prevent large Voronoi cells near the boundary, which
%     otherwise slow down the calculations (in the function
%     constructvoronoicell) 
%   See also
%     help constructvoronoicell

xx = x; yy = y;
n = min([length(x) length(y) length(f)]);
x = x(1:n); y = y(1:n); f = f(1:n);

c = (f-min(f))/(max(f)-min(f));

vc = cell(n,1);
holdstatus = ishold;

for v = 1:n,
   vc = constructvoronoicell(v,xx,yy);
   fill(vc(:,1),vc(:,2),c(v)*[1 1 1])
   hold on
end
if holdstatus == false, hold off, end
   

