function dummy = plotedges(E,x,y,varargin)

% plotedges - ThreshLab2/Triangulations --- plots edges in 2D or 3D mesh
%   Usage
%      plotedges(E,x,y,plotoptions)
%      plotedges(E,x,y,z,plotoptions)
%   Inputs
%      E                ne x 2 integer matrix
%      x                vector of x-coordinates of vertices
%      y                vector of y-coordinates of vertices
%      z                vector of z-coordinates of vertices
%   Optional input
%      matlab's options for plot and plot3
%   Outputs
%      (none)
%   Description
%   See also
%      help plotmesh

h = ishold;
dimension = 2;
plotoptions = {};
N = length(x);
if N ~= length(y),
   warning('x and y have dissimilar lengths')
   N = min(N,length(y));
end
if max(E) > N,
   error('list of edges has indices beyond range of (x,y)')
end
if min(E) < 1,
   error('list of edges has zero or negative indices')
end
z = zeros(size(x));
nvarargin = length(varargin);
if nvarargin > 0,
   k = 1;
   vark = varargin{1};
   if length(vark) == N, z = vark; k = 2; dimension = 3; end
   % if max(z) < eps & min(z) > -eps, dimension = 2; z = zeros(size(x)); end
   plotoptions = varargin(k:nvarargin);
end
nE = size(E,1);
for e = 1:nE
   x1 = x(E(e,1));
   x2 = x(E(e,2));
   y1 = y(E(e,1));
   y2 = y(E(e,2));
   z1 = z(E(e,1));
   z2 = z(E(e,2));
   if dimension == 2,
      plot([x1 x2],[y1 y2],plotoptions{:})
   else
      plot3([x1 x2],[y1 y2],[z1 z2],plotoptions{:})
   end
   hold on
end
if ~h
   hold off
end
xmin = min(x);
xmax = max(x);
ymin = min(y);
ymax = max(y);
zmin = min(z);
zmax = max(z);
if dimension == 2,
   axis([xmin xmax ymin ymax])
end

