
function LL = LLmarg0inflLaplaceplusnormal(pp,aa,stdev,y);

% LLmarg0inflLaplaceplusnormal -- marginal log-likelihood for zero inflated
% Laplace + standard normal noise
%   Usage
%      LL = LLmarg0inflLaplaceplusnormal(pp,aa,stdev,Y);
%      LL = LLmarg0inflLaplaceplusnormal(pa,stdev,Y);
%   Inputs
%      Y     observations
%      pp    sparsity parameter value
%      aa    parameter Laplace density
%      pa    [pp aa] or [pp; aa]
%      stdev value for st.dev. of noise
%   Outputs
%      LL    marginal log likelihood of parameters given Y
%   Description
%      The model is Y = X + stdev*Z, with
%      p = P(X =/= 0)
%      X|X=/=0 ~ Laplace(a)
%      Z ~ NID(0,1)
%   See also
%     help LLmarg0inflCauchyJSplusnormal


if nargin < 4,
   y = stdev;
   stdev = aa;
   pa = pp;
   [s1 s2] = size(pa);
   if s2 == 2,
      pp = pa(:,1); aa = pa(:,2);
   elseif s1 == 2,
      pp = pa(1,:); aa = pa(2,:);
   else
      error('inconsistent input variables')
   end
end
na = length(aa); np = length(pp);
if na < np,
   aa = aa(1)*ones(size(pp));
elseif np < na,
   pp = pp(1)*ones(size(aa));
end
np = length(pp); 
LL = zeros(size(pp));
for i = 1:np, 
   p = pp(i);
   a = aa(i);
   LL(i) = sum(log(p*laplaceplusnormalpdf(y,a,stdev) + (1-p)*gauss(y,stdev)));
end
