
function F = zeroinflatedlaplaceplusnormalcdf(x,p,a,sigma);

% laplaceplusnormalcdf -- cumulative distribution function of Y = X*T+sigma*Z
%                         with X ~ Bernoulli(p)
%                              T ~ Laplace(a)
%                              Z ~ N(0,1)
%   Usage
%     F = zeroinflatedlaplaceplusnormalcdf(x,p,a,sigma);
%   Inputs
%     x     value in which cdf is evaluated
%     p     parameter of Bernoulli distribution (default 0.05)
%     a     parameter of Laplace distribution (default 0.5)
%     sigma st.dev. of normal distribution (default 1)
%   Outputs
%     F     cdf of Y = X*T+sigma*Z
%   Description
%     the definition of the Laplace distribution used here has pdf
%     f(t) = (a/2)*exp(-a*|t|)
%     i.e., T ~ Laplace(a), then E(T) = 0; var(T) = 2/a^2
%   See also
%     help laplaceplusnormalcdf
%     help JScauchyplusnormalcdf


if nargin < 4, sigma = 1; end
if nargin < 3, a = 1/2; end
if nargin < 2, p = 0.05; end

F = p*laplaceplusnormalcdf(x,a,sigma) + (1-p)*cumgauss(x,sigma);

