
% This file produces the figures that compare the expressions of the mirror
% penalty with the penalty proposed by Birgé and Massart (2007), Prob. Theory
% and Related Fields, 138, pp 33-73
p = 0.05;
stdev = 1;
a = 1/5;
tmax = 30*stdev;
N = 1000;
tt = (0:N)/N*tmax;

xx0 = 2*(1-cumgauss(tt,stdev));
xx1 = 2*(1-p)*(1-cumgauss(tt,stdev)) + ...
      2*p*(1-laplaceplusnormalcdf(tt,a,stdev));

plot(xx1,xx0)
hold on
plot(xx1,xx1,'r')
hold off

penmirror = 2*xx1*stdev^2+4*stdev^2*tt.*gauss(tt,stdev);
plot(xx1,2*xx1*stdev^2,'color',0.3*[1 1 1],'linewidth',3)
hold on
plot(xx1,penmirror,'color','k','linewidth',3)
if exist('constantBM') ~= 1, constantBM = 1; end
constantBM
K = constantBM;
penBM = K*stdev^2*xx1.*(1+2*log(1./xx1)+2*sqrt(log(1./xx1)));
plot(xx1,penBM,'k--','linewidth',3)
hold off
aa = axis;
axis off
set(gca,'fontsize',18,'fontweight','bold')
drawaxes
text(aa(1) + [aa(2)-aa(1)]*3/4,aa(4)/30,'model size n_1',...
        'fontsize',18,'fontweight','bold')
legend('Mallows''s penalty','Mirror penalty','Birge-Massart pen.',...
       'location',[0.5 0.25 0.45 0.2])
% 'location' = [SWcorner x, SWcorner y,width,height]


tt0 = invcumgauss(1-xx1/2,stdev);
pen0 = 2*xx1*stdev^2+4*stdev^2*tt0.*gauss(tt0,stdev);
figure(2)
plot(xx1,xx0,'color','k','linewidth',3)
hold on
plot(xx1,xx1,'color',0.3*[1 1 1],'linewidth',3)
hold off
aa = [0 0.12 -0.01 0.1];
axis(aa)
axis off
axis equal
drawaxes
text(aa(2)*0.8,aa(4)*0.9,'y=x_1',...
        'fontsize',18,'fontweight','bold')
text(aa(2)*0.6,aa(4)*0.35,...
        'y=1-F_{|\epsilon|}(Q_{|Y|}(1-x1))',...
        'fontsize',18,'fontweight','bold')
text(aa(1) + [aa(2)-aa(1)]*7/8,aa(4)/30,'x_1 = n_1/n',...
        'fontsize',18,'fontweight','bold')
hold on
for k = 1:6,
   plot(k*[0.02 0.02],0.001*[-1 1],'color','k','linewidth',3)
   text((k-0.3)*0.02,-0.005,num2str(k*0.02,'%3.2f'),...
        'fontsize',18,'fontweight','bold')
end
hold off


