% This routine illustrates the working of the mirror corrected Mallows's Cp as
% stopping criterium in a least angle regression routine for use in variable
% selection without shrinkage.
%
% Set 
% degreeofsparsity =   0.05;
% givensizeX = 1; m = 600; n = 600;
% typedesign = 'randomuniform';
% prior = ' binary';
%
% for the settings used for Table 2 in the paper `Information criteria for
% variable selection under sparsity' (and run 200 times to obtain the raw
% values summarized in this table)
  

% givensizeX = true; m = 400; n = 400; degreeofsparsity = 0.15; realrandom = 1;
% kmax = 350;
if exist('typedesign') ~= 1, typedesign = 'random'; end
if exist('realrandom') ~= 1, realrandom = 0; end
if exist('givensizeX') ~= 1, givensizeX = false; end
   if ~givensizeX, m = 1000; n = 200; end % n = number of observations
clear givensizeX
if exist('snratio') ~= 1, snratio = 10; end
if exist('degreeofsparsity') ~= 1, degreeofsparsity = 0.05; end
if exist('bandwidth') ~= 1, bandwidth = 1; end
if exist('singvalues') ~= 1, singvalues = 1; end
if exist('n_singval') ~= 1, n_singval = 1; end
if exist('standardize') ~= 1, standardize = 0; end
if exist('normalizedcolumnsX') ~= 1, normalizedcolumnsX = 2; end
if exist('domontecarlo') ~= 1, domontecarlo = 0; end
if exist('useexistingobservations') ~= 1, useexistingobservations = 0; end
if exist('prior') ~= 1, prior = 'Laplace'; end
fontsize = 14;
fontopt = {'fontsize',fontsize, 'fontweight','bold'};
figwidth0 = 1050; figsize = [figwidth0 420];


p = degreeofsparsity;

if useexistingobservations == 0,
  [Y X beta stdev Z] = ...
  setupsimulationYisXbetaplussigmaZ(typedesign,m,n,p,snratio,realrandom,...
                                'bandwidth',bandwidth,...
                                'singularvalues',singvalues,...
                                'n_singval',n_singval,...
                                'normalizedcolumns',normalizedcolumnsX,...
                                'prior',prior);
end
typedesign2 = [typedesign  '   '];
if typedesign2(1:3) == 'eye'
   if exist('dosubsample') ~= 1, dosubsample = 0; end
   if dosubsample == 1,
      X = X(1:n,1:m);
      Y = Y(1:n);
      Z = Z(1:n);
   end
   clear dosubsample
end

Xbeta = X*beta;
[n m] = size(X);
noise = Y-Xbeta;
stdevXTeps = sqrt(var2(X'*noise));
stdevXTeps2 = stdev*sqrt(var2(X'*Z));

if exist('kmax') ~= 1, kmax = n; end

% Oracle selection
[betahatO muhatO xO CpxO thrO AoptO] = LARSmodified(Xbeta,X,0,kmax);
disp('finished computation of betahatO,muhatO,xO,CpxO,thrO,AoptO,')
disp('using LARSmodified applied to input')
disp('X*beta, without noise (Oracle values)')
disp('-------------------------------------------------------------')

% Lasso-shrinkage selection and estimation
[betahatS muhatS xS CpxS thrS AoptS] = LARSmodified(Y,X,stdev,kmax);
disp('computed betahatS,muhatS,xS,CpxS,thrS,AoptS with LARSmodified from Y')
disp('-------------------------------------------------------------')

% Lasso selection + LS estimation
[betahatLS muhatLS xLS CpxLS thrLS AoptLS] = LARSell0(Y,X,stdev,kmax);
XAoptLS = X(1:n,AoptLS);
betahatLSLSA = (XAoptLS'*XAoptLS)\(XAoptLS'*Y);
betahatLSLS = zeros(size(betahatLS));
betahatLSLS(AoptLS) = betahatLSLSA;

[PEO kO] = samplePEonS(xO,Y,X,beta,0);
CpO = CponSmodelsize(xO,Y,X,stdev,0); 

[PElasso klasso] = samplePEonS(xS,Y,X,beta,thrS);
Cplasso = CponSmodelsize(xS,Y,X,stdev,thrS);
gcvlasso = GCVonSmodelsize(xS,Y,X,thrS);
% Plots of PElasso, Cplasso, and gcvlasso illustrate the fact that GCV-lasso
% suffers from its singularity near threshold/shrinkage zero (maximum model)
% plot(klasso,PElasso,'r','linewidth',2)
% axy = axis; axy(2) = kmax;
% hold on
% plot(klasso,Cplasso,'b','linewidth',2)
% plot(klasso,gcvlasso,'m','linewidth',2)
% hold off
% axis(axy)


[PELS kLS] = samplePEonS(xLS,Y,X,beta,0);
CpLS = CponSmodelsize(xLS,Y,X,stdev,0);
CpLSmirr = CpxLS(2:end);
gcvLS = GCVonSmodelsize(xLS,Y,X,0);

figure(1)
figpos = get(gcf,'position');
figpos(3:4) = figsize; papersize = figsize/96; figpaperpos = [0 0 papersize];
set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)
plot(kO,PEO,'m','linewidth',2)
hold on
plot(kO,CpO,'b','linewidth',2)
plot(kLS,CpLS,'k','linewidth',2)
plot(kLS,CpLSmirr,'r','linewidth',2)
plot(kLS,PELS,'g','linewidth',2)
legend('PE oracle','Cp oracle','Cp LS','Cp LS + mirr','PE LS',fontopt{:})
% plot(kLS,CpxLS(2:end),'k--','linewidth',2)
% plot(kLS,CpxS(2:end),'k--','linewidth',2)
hold off
kappatick = bestticks(kLS);
axy = axis; axy(2) = kmax*1.1; axis(axy);
axis off
drawaxes('xticks',kappatick,fontopt{:});
xlabel('\kappa: number of components in model',fontopt{:})

figure(2)
figpos = get(gcf,'position');
figpos(3:4) = figsize; papersize = figsize/96; figpaperpos = [0 0 papersize];
set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)
plot(kLS,CpLSmirr-CpLS,'color','r','linewidth',2)
hold on
plot(kLS,PELS-CpLS,'color','b','linewidth',2)
hold off
axy = axis; axy(2) = kmax*1.1; axis(axy);
axis off
drawaxes('xticks',kappatick,fontopt{:});
legend('estimated mirror','PE least squares - PE lasso',fontopt{:})
title('exact and estimated mirror functions',fontopt{:})
