
function [wt, thr] = minmsesoft(v,w,s)

% minmsesoft -- apply soft threshold with minimum MSE threshold
%                    MSE = Loss = mean squared error
%  Usage
%    [wt, thr] = minmsesoft(v,w);
%    [wt, thr] = minmsesoft(v,w,s);
%  Inputs
%    v      noise-free input vector
%    w      observed input vector
%    s      vector of size(w) (default value is 1)
%  Outputs
%    wt     thresholded vector
%    thr    minimum MSE threshold 
%  Description
%    Applies minimum MSE soft threshold ST(w,s*thr) to all elements of w
%  Note
%
%  See also
%    help MSEsoft
%    help minmsethreshest

if nargin == 3,
   [wt, thr] = minmsethreshest(v,w,s,1);
else
   [wt, thr] = minmsethreshest(v,w,1);
end

% Copyright (c) Maarten Jansen
%
% This software is part of ThreshLab and is copyrighted material. 

