
function bias = hardbias(l,beta,stdev);

% hardbias -- bias in hard thresholding data with normal noise
%  Usage
%    bias = hardbias(t,beta,stdev);
%  Inputs
%    t      threshold, or vector of thresholds
%    beta   vector of noise-free data
%    stdev  standard deviation of normal noise (to be added to beta)
%  Outputs
%    bias   norm of hard threshold bias
%  Description
%    computes bias when thresholding Y = beta+noise where noise ~ N(0,stdev^2)
%    i.e., E(HT(Y)) - beta where HT = hard-threshold function
%  Note
%  See also:
%    help hardrisk
%    help HT


betacol = column(beta);
lrow = row(l);
n = length(beta);
m = length(l);
l = repmat(lrow,n,1);
beta = repmat(betacol,1,m);

Ebetahat1 = stdev^2*(gauss(l-beta,stdev) - gauss(l+beta,stdev));
Ebetahat3 = beta.*(1 - cumgauss(l-beta,stdev) - cumgauss(l+beta,stdev));
Ebetahat = Ebetahat1 + Ebetahat3;
bias = sqrt(sum(Ebetahat.*Ebetahat)/n);

% Copyright (c) Maarten Jansen
% 
% This software is part of ThreshLab and is copyrighted material. 
