
function Rs = softrisk(t,beta,stdev);

% softrisk -- expected L2-loss in soft thresholding data with normal noise
%  Usage
%    Rs = softrisk(t,beta,stdev);
%  Inputs
%    t      threshold, or vector of thresholds
%    beta   vector of noise-free data
%    stdev  standard deviation of normal noise (to be added to beta)
%  Outputs
%    Rs     soft threshold risk = expected L2-loss
%  Description
%    computes risk when thresholding w = beta+noise where noise ~ N(0,stdev^2)
%  Note
%    This routine cannot be used for plotting the risk in a single coefficient
%    as a function of that coefficient's value: the function takes all values
%    of beta as a data vector.
%  See also:
%    help hardrisk
%    help softbias
%    help minrisksoftthr


if nargin < 3, stdev = 1; end
if nargin < 2, beta = 0; end
betacol = column(beta);
trow = row(t);
n = length(beta);
m = length(t);
t = repmat(trow,n,1);
beta = repmat(betacol,1,m);
stdev2 = stdev*stdev;
tbeta = t+beta;
t_beta = t-beta;

Rs1 = 2*(stdev2+t.*t)-beta.^2;
Rs2 = (cumgauss(tbeta,stdev)+cumgauss(t_beta,stdev)).*(beta.^2-stdev2-t.*t);
Rs3 = -stdev2*(t_beta.*gauss(tbeta,stdev)+tbeta.*gauss(t_beta,stdev));
Rs = Rs1+Rs2+Rs3;

Rs = sum(Rs,1)/n;

% Copyright (c) Maarten Jansen
% 
% This software is part of ThreshLab and is copyrighted material. 
