function w = FAUHTfromrefinement(x,y,cc);

%  FAUHTfromrefinement -- forward unbalanced Haar transform
%                         for given order of refinement
%   Usage
%     w = FAUHTfromrefinement(x,y,cc);
%   Inputs
%     x      real vector; grid-locations of observations (time, space)
%     y      real vector or matrix; response variables
%     cc     permutation of (1:length(y)); ordered list of splitting points
%   Outputs
%     w       vector of size(y) containing offset/detail coefficients
%   Description
%     Forward unbalanced Haar transform, for given order of refinement
%     Can be used to compute transform matrix (take eye(length(x)) as input)
%   Note
%     The name of this function, FAUHTfromrefinement, has an A in it, which
%     stands for "Adaptive". This function is, however, not adaptive. The A is
%     kept in the name, to emphasize the link between this function and the
%     function FAUHT.
%   See also
%     help FAUHT   (for adaptive unbalanced Haar transform)

n = length(x); transpose = false;
if nargin<2, y = x; x = makegrid(0,n); end
x = column(x); if size(y,1) ~= n, transpose = true; y=y'; end
m = size(y,2);
M = row(initmom(x)); M([1 n]) = 2*M([1 n]);
w = ones(n,1)*y(1,1:m);
w(1,1:m) = M*y/sum(M);
II = [0 n];
for k = 2:n,
   c = cc(k);
   i = max(find(II<c));
   II = [II(1:i) c II(i+1:k)];
   IL = (II(i)+1:II(i+1)); IR = (II(i+1)+1:II(i+2));
   MIL = sum(M(IL)); MIR = sum(M(IR));
   w(k,1:m) = M(IR)*y(IR,1:m)/MIR-M(IL)*y(IL,1:m)/MIL;
end
if transpose==true, w = w'; end
