
function omega = argmaxLKappaplusalphaLambda(Kappa,Lambda,Sigma);

% argmaxLKappaplusalphaLambda - ThreshLab/Trees
%   Usage
%     omega = argmaxLKappaplusalphaLambda(Kappa,Lambda,Sigma);
%   Inputs
%     Kappa       m x m concentration matrix
%     Lambda      m x m gradient matrix
%     Sigma       m x m covariance matrix
%   Outputs
%     omega       real number maximising 
%                 g(omega) = l(Kappa+omega*Lambda), where
%                 l(K) = log(det(K))-trace(K*Sigma)
%   Description
%     finds maximum likelihood K = Kappa+omega*Lambda in search direction
%     defined by Lambda. (See maxLsparseKappa)
%   Remark
%     Non-symmetric inputs may lead to imaginary results
%   See also
%     help maxLsparseKappa


tol = 1.e-6;
n = size(Kappa,1);
A = Kappa\Lambda;
B = Sigma*Lambda;
[E Delta] = eig(A);
d = diag(Delta);
% F = E\B*E;
trB = trace(B);
omega1 = 0;
omega2 = min(eig(Kappa))/abs(min(eig(Lambda)));
while omega2-omega1>tol
   omega = (omega1+omega2)/2;
   gprime = sum(d./(1+d*omega))-trB;
   if gprime>0, omega1 = omega; else, omega2 = omega; end
end
