
function level = levelintree(parents)

% levelintree -- ThreshLab/Trees; finds levels/depths of all nodes in a tree
%   Usage
%     level = levelintree(parents);
%     level = levelintree(children);
%   Inputs
%     parents  integer vector, representing the hierarchy, i.e.,
%              containing for each node the index of its ancestor 
%              (default = floor((1:n)/2), i.e., maximal/full binary tree)
%     children integer matrix or integer cell 
%              containing for each node the indices of its children
%   Outputs
%     level    integer vector of length(parents), depth of all nodes
%   Description
%     The routine rests on the assumption that each node has at most one parent
%   See also
%     help parentschildren

[parents children] = parentschildren(parents,'cell');
n = length(parents);
nnodeswithchildren = length(children);
currentlevel = find(parents==0);
level = nan(n,1); l = 0; level(currentlevel) = l; m = n;
while any(isnan(level(1:n))),
   nextlevel = [];
   for p=currentlevel, 
      if p<= nnodeswithchildren,
         c = children{p};
         nextlevel = [nextlevel c];
      end
   end
   currentlevel = nextlevel; l=l+1; level(currentlevel) = l;
end

% Copyright (c) Maarten Jansen
% 
% This software is part of ThreshLab and is copyrighted material.
