function mhat = montecarlomirrorAUHTpoisson(x,mu,gam);

% montecarlomirrorAUHTpoisson - ThreshLab/Trees - Mirror correction in 
%                            regression tree pruning with Poisson observations
%   Usage
%     mhat = montecarlomirrorAUHTpoisson(x,mu,gam);
%   Inputs
%     x    locations (time/space) of observations (default equispaced on [0,1])
%     mu   Poisson intensities (expected responses) in x
%     gam  parameter in FAUHT
%   Outputs
%     mhat numerically (Monte-Carlo) computed approximation of offset between
%          degrees of freedom after selection and selection size (mirror)
%   Note
%     The Poisson intensity mu also fixes the variances, which are included in
%     the definition of the mirror (see also Note in montecarlomirrorAUHT)
%   See also
%     help montecarlomirrorAUHT
%     help FAUHT


n = length(x);
if nargin<2, mu = x; x = makegrid(n,0); end
if nargin<3, gam = 1; end
if n==1, n = x; x = makegrid(n,0); end
if length(mu)==1,
   gam = mu; mu = x; n = length(mu); x = makegrid(n,0);
end

Y = poissonnoise(mu);
[w cc parents] = FAUHT(x,Y,gam);
I = eye(n);
Wt = FAUHTfromrefinement(x,I,cc);
v = FAUHTfromrefinement(x,mu,cc);
Sigmaw = Wt*diag(mu)*Wt';
stdevw = row(sqrt(diag(Sigmaw)));
w = row(w); v = row(v);
w = w./stdevw;
v = v./stdevw;
Z = w-v;

[sumw2subtree subtrees] = maxmassubtree(w.^2,parents);
sumZ2subtree = zeros(1,n);
for k=1:n, sumZ2subtree(k) = norm(Z(subtrees{k}))^2; end

mhat = (sumZ2subtree-(1:n))/n;
