
function [parents children] = parentschildren(parents,varargin),

% parentschildren -- ThreshLab/Trees; finds parents and children in trees
%   Usage
%     [parents children] = parentschildren(parents)
%     [parents children] = parentschildren(children)
%     children = parentschildren(parents)
%     parents = parentschildren(children)
%   Inputs
%     parents  integer vector, representing the hierarchy, i.e.,
%              containing for each node the index of its ancestor 
%              (default = floor((1:n)/2), i.e., maximal/full binary tree)
%     children integer matrix or integer cell 
%              containing for each node the indices of its children
%   Outputs
%     parents  integer vector
%     children integer matrix or integer cell
%   Description
%     The routine rests on the assumption that each node has at most one parent
%   See also

outputcell = false;
nvarargin = length(varargin);
k = 0;
while k < nvarargin, k=k+1; vark = varargin{k}; if ischar(vark), switch(vark)
   case {'cell','outputcell'},
      outputcell = true;
   end
end, end


if iscell(parents), % convert to matrix, filling up with zeros
                    % We use the variable name parents, although we know at
                    % this point that these are actually the children
   np = length(parents);
   nc = 1;
   parents2 = zeros(np,nc);
   for p=1:np,
      parentsp = row(parents{p});
      ncc = length(parentsp);
      if ncc>nc, parents2 = [parents2 zeros(np,ncc-nc)]; nc = ncc; end
      parents2(p,1:ncc) = parentsp;
   end
   parents = parents2;
end
childrenout = false;
if min(size(parents))>1,
   children = parents;
   % if size(children,2)>size(children,1), children = children'; end
   n = max(max(children));
   parents = zeros(1,n);
   for c = 1:size(children,2),
      cc = find(children(1:end,c)>0);
      parents(children(cc,c)) = cc;
   end
else
   n = length(parents);
   m = max(parents); 
   children = cell(m,1);
   nc = zeros(m,1);
   for c=1:n, 
      p = parents(c); 
      if p>0, nc(p) = nc(p)+1; children{p} = [children{p} c]; end
   end
   if nargout == 1, childrenout = true; end
end
if iscell(children) & outputcell==false,
   children2 = zeros(m,max(nc));
   for p=1:m,
      children2(p,1:nc(p)) = children{p};
   end
   children = children2;
elseif ~iscell(children) & outputcell==true,
   m = size(children,1);
   children2 = cell(m,1);
   for p=1:m,
      childrenp = children(p,:);
      c = find(childrenp); childrenp = childrenp(c);
      children2{p} = childrenp;
   end
   children = children2;
end
if childrenout, parents = children; end

% Copyright (c) Maarten Jansen
% 
% This software is part of ThreshLab and is copyrighted material. 
